# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: src/ray/protobuf/gcs_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as src_dot_ray_dot_protobuf_dot_common__pb2
from . import gcs_pb2 as src_dot_ray_dot_protobuf_dot_gcs__pb2
from . import pubsub_pb2 as src_dot_ray_dot_protobuf_dot_pubsub__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"src/ray/protobuf/gcs_service.proto\x12\x07ray.rpc\x1a\x1dsrc/ray/protobuf/common.proto\x1a\x1asrc/ray/protobuf/gcs.proto\x1a\x1dsrc/ray/protobuf/pubsub.proto\":\n\rAddJobRequest\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x15.ray.rpc.JobTableDataR\x04\x64\x61ta\"9\n\x0b\x41\x64\x64JobReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"/\n\x16MarkJobFinishedRequest\x12\x15\n\x06job_id\x18\x01 \x01(\x0cR\x05jobId\"B\n\x14MarkJobFinishedReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\";\n\x14GetAllJobInfoRequest\x12\x19\n\x05limit\x18\x01 \x01(\x05H\x00R\x05limit\x88\x01\x01\x42\x08\n\x06_limit\"{\n\x12GetAllJobInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x39\n\rjob_info_list\x18\x02 \x03(\x0b\x32\x15.ray.rpc.JobTableDataR\x0bjobInfoList\"M\n\x15ReportJobErrorRequest\x12\x34\n\tjob_error\x18\x01 \x01(\x0b\x32\x17.ray.rpc.ErrorTableDataR\x08jobError\"A\n\x13ReportJobErrorReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x15\n\x13GetNextJobIDRequest\"V\n\x11GetNextJobIDReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x15\n\x06job_id\x18\x02 \x01(\x05R\x05jobId\"D\n\x13GetActorInfoRequest\x12\x19\n\x08\x61\x63tor_id\x18\x01 \x01(\x0cR\x07\x61\x63torId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x82\x01\n\x11GetActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x41\n\x10\x61\x63tor_table_data\x18\x02 \x01(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\"S\n\x18GetNamedActorInfoRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rray_namespace\x18\x02 \x01(\tR\x0crayNamespace\"\xb7\x01\n\x16GetNamedActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x41\n\x10\x61\x63tor_table_data\x18\x02 \x01(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\x12.\n\ttask_spec\x18\x03 \x01(\x0b\x32\x11.ray.rpc.TaskSpecR\x08taskSpec\"d\n\x16ListNamedActorsRequest\x12%\n\x0e\x61ll_namespaces\x18\x01 \x01(\x08R\rallNamespaces\x12#\n\rray_namespace\x18\x02 \x01(\tR\x0crayNamespace\"\x87\x01\n\x14ListNamedActorsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x43\n\x11named_actors_list\x18\x02 \x03(\x0b\x32\x17.ray.rpc.NamedActorInfoR\x0fnamedActorsList\"\xe0\x02\n\x16GetAllActorInfoRequest\x12$\n\x0eshow_dead_jobs\x18\x01 \x01(\x08R\x0cshowDeadJobs\x12\x19\n\x05limit\x18\x02 \x01(\x03H\x00R\x05limit\x88\x01\x01\x12\x46\n\x07\x66ilters\x18\x03 \x01(\x0b\x32\'.ray.rpc.GetAllActorInfoRequest.FiltersH\x01R\x07\x66ilters\x88\x01\x01\x1a\xa6\x01\n\x07\x46ilters\x12\x1e\n\x08\x61\x63tor_id\x18\x01 \x01(\x0cH\x00R\x07\x61\x63torId\x88\x01\x01\x12\x1a\n\x06job_id\x18\x02 \x01(\x0cH\x01R\x05jobId\x88\x01\x01\x12=\n\x05state\x18\x03 \x01(\x0e\x32\".ray.rpc.ActorTableData.ActorStateH\x02R\x05state\x88\x01\x01\x42\x0b\n\t_actor_idB\t\n\x07_job_idB\x08\n\x06_stateB\x08\n\x06_limitB\n\n\x08_filters\"\xbe\x01\n\x14GetAllActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x41\n\x10\x61\x63tor_table_data\x18\x02 \x03(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\x12\x14\n\x05total\x18\x03 \x01(\x03R\x05total\x12!\n\x0cnum_filtered\x18\x04 \x01(\x03R\x0bnumFiltered\"q\n\x16KillActorViaGcsRequest\x12\x19\n\x08\x61\x63tor_id\x18\x01 \x01(\x0cR\x07\x61\x63torId\x12\x1d\n\nforce_kill\x18\x02 \x01(\x08R\tforceKill\x12\x1d\n\nno_restart\x18\x03 \x01(\x08R\tnoRestart\"B\n\x14KillActorViaGcsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x15\n\x13GetClusterIdRequest\"^\n\x11GetClusterIdReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x1d\n\ncluster_id\x18\x02 \x01(\x0cR\tclusterId\"H\n\x13RegisterNodeRequest\x12\x31\n\tnode_info\x18\x01 \x01(\x0b\x32\x14.ray.rpc.GcsNodeInfoR\x08nodeInfo\"?\n\x11RegisterNodeReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x17\n\x15GetAllNodeInfoRequest\"}\n\x13GetAllNodeInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12:\n\x0enode_info_list\x18\x02 \x03(\x0b\x32\x14.ray.rpc.GcsNodeInfoR\x0cnodeInfoList\":\n\x11\x43heckAliveRequest\x12%\n\x0eraylet_address\x18\x01 \x03(\tR\rrayletAddress\"\x81\x01\n\x0f\x43heckAliveReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x1f\n\x0bray_version\x18\x02 \x01(\tR\nrayVersion\x12!\n\x0craylet_alive\x18\x03 \x03(\x08R\x0brayletAlive\"\x1a\n\x18GetInternalConfigRequest\"\\\n\x16GetInternalConfigReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x16\n\x06\x63onfig\x18\x02 \x01(\tR\x06\x63onfig\".\n\x13GetResourcesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\"\xe2\x01\n\x11GetResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12G\n\tresources\x18\x02 \x03(\x0b\x32).ray.rpc.GetResourcesReply.ResourcesEntryR\tresources\x1aX\n\x0eResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.ray.rpc.ResourceTableDataR\x05value:\x02\x38\x01\"B\n\x14\x44\x65leteResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"!\n\x1fGetAllAvailableResourcesRequest\"\x8f\x01\n\x1dGetAllAvailableResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x42\n\x0eresources_list\x18\x02 \x03(\x0b\x32\x1b.ray.rpc.AvailableResourcesR\rresourcesList\"R\n\x1aReportResourceUsageRequest\x12\x34\n\tresources\x18\x01 \x01(\x0b\x32\x16.ray.rpc.ResourcesDataR\tresources\"F\n\x18ReportResourceUsageReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"]\n\x1aReportWorkerFailureRequest\x12?\n\x0eworker_failure\x18\x01 \x01(\x0b\x32\x18.ray.rpc.WorkerTableDataR\rworkerFailure\"F\n\x18ReportWorkerFailureReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"3\n\x14GetWorkerInfoRequest\x12\x1b\n\tworker_id\x18\x01 \x01(\x0cR\x08workerId\"\x86\x01\n\x12GetWorkerInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x44\n\x11worker_table_data\x18\x02 \x01(\x0b\x32\x18.ray.rpc.WorkerTableDataR\x0fworkerTableData\">\n\x17GetAllWorkerInfoRequest\x12\x19\n\x05limit\x18\x01 \x01(\x03H\x00R\x05limit\x88\x01\x01\x42\x08\n\x06_limit\"\x9f\x01\n\x15GetAllWorkerInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x44\n\x11worker_table_data\x18\x02 \x03(\x0b\x32\x18.ray.rpc.WorkerTableDataR\x0fworkerTableData\x12\x14\n\x05total\x18\x03 \x01(\x03R\x05total\"Q\n\x14\x41\x64\x64WorkerInfoRequest\x12\x39\n\x0bworker_data\x18\x01 \x01(\x0b\x32\x18.ray.rpc.WorkerTableDataR\nworkerData\"@\n\x12\x41\x64\x64WorkerInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"D\n\x12\x43reateActorRequest\x12.\n\ttask_spec\x18\x01 \x01(\x0b\x32\x11.ray.rpc.TaskSpecR\x08taskSpec\"\x89\x02\n\x10\x43reateActorReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x35\n\ractor_address\x18\x02 \x01(\x0b\x32\x10.ray.rpc.AddressR\x0c\x61\x63torAddress\x12\x42\n\rborrowed_refs\x18\x03 \x03(\x0b\x32\x1d.ray.rpc.ObjectReferenceCountR\x0c\x62orrowedRefs\x12>\n\x0b\x64\x65\x61th_cause\x18\x04 \x01(\x0b\x32\x18.ray.rpc.ActorDeathCauseH\x00R\ndeathCause\x88\x01\x01\x42\x0e\n\x0c_death_cause\"F\n\x14RegisterActorRequest\x12.\n\ttask_spec\x18\x01 \x01(\x0b\x32\x11.ray.rpc.TaskSpecR\x08taskSpec\"@\n\x12RegisterActorReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"l\n\x1b\x43reatePlacementGroupRequest\x12M\n\x14placement_group_spec\x18\x01 \x01(\x0b\x32\x1b.ray.rpc.PlacementGroupSpecR\x12placementGroupSpec\"G\n\x19\x43reatePlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"K\n\x1bRemovePlacementGroupRequest\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\"G\n\x19RemovePlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"H\n\x18GetPlacementGroupRequest\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\"\xa3\x01\n\x16GetPlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12]\n\x1aplacement_group_table_data\x18\x02 \x01(\x0b\x32 .ray.rpc.PlacementGroupTableDataR\x17placementGroupTableData\"B\n\x1bGetAllPlacementGroupRequest\x12\x19\n\x05limit\x18\x01 \x01(\x03H\x00R\x05limit\x88\x01\x01\x42\x08\n\x06_limit\"\xbc\x01\n\x19GetAllPlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12]\n\x1aplacement_group_table_data\x18\x02 \x03(\x0b\x32 .ray.rpc.PlacementGroupTableDataR\x17placementGroupTableData\x12\x14\n\x05total\x18\x03 \x01(\x03R\x05total\"S\n#WaitPlacementGroupUntilReadyRequest\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\"O\n!WaitPlacementGroupUntilReadyReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"X\n\x1dGetNamedPlacementGroupRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rray_namespace\x18\x02 \x01(\tR\x0crayNamespace\"\xa8\x01\n\x1bGetNamedPlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12]\n\x1aplacement_group_table_data\x18\x02 \x01(\x0b\x32 .ray.rpc.PlacementGroupTableDataR\x17placementGroupTableData\"(\n\rDrainNodeData\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\"R\n\x10\x44rainNodeRequest\x12>\n\x0f\x64rain_node_data\x18\x01 \x03(\x0b\x32\x16.ray.rpc.DrainNodeDataR\rdrainNodeData\"*\n\x0f\x44rainNodeStatus\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\"\x82\x01\n\x0e\x44rainNodeReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x44\n\x11\x64rain_node_status\x18\x02 \x03(\x0b\x32\x18.ray.rpc.DrainNodeStatusR\x0f\x64rainNodeStatus\"F\n\x14InternalKVGetRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x1c\n\tnamespace\x18\x02 \x01(\x0cR\tnamespace\"V\n\x12InternalKVGetReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\"M\n\x19InternalKVMultiGetRequest\x12\x12\n\x04keys\x18\x01 \x03(\x0cR\x04keys\x12\x1c\n\tnamespace\x18\x02 \x01(\x0cR\tnamespace\"7\n\rMapFieldEntry\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\"w\n\x17InternalKVMultiGetReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x30\n\x07results\x18\x02 \x03(\x0b\x32\x16.ray.rpc.MapFieldEntryR\x07results\"z\n\x14InternalKVPutRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\x12\x1c\n\toverwrite\x18\x03 \x01(\x08R\toverwrite\x12\x1c\n\tnamespace\x18\x04 \x01(\x0cR\tnamespace\"]\n\x12InternalKVPutReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x1b\n\tadded_num\x18\x02 \x01(\x05R\x08\x61\x64\x64\x65\x64Num\"j\n\x14InternalKVDelRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x1c\n\tnamespace\x18\x02 \x01(\x0cR\tnamespace\x12\"\n\rdel_by_prefix\x18\x03 \x01(\x08R\x0b\x64\x65lByPrefix\"a\n\x12InternalKVDelReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x1f\n\x0b\x64\x65leted_num\x18\x02 \x01(\x05R\ndeletedNum\"I\n\x17InternalKVExistsRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x1c\n\tnamespace\x18\x02 \x01(\x0cR\tnamespace\"[\n\x15InternalKVExistsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x16\n\x06\x65xists\x18\x02 \x01(\x08R\x06\x65xists\"M\n\x15InternalKVKeysRequest\x12\x16\n\x06prefix\x18\x01 \x01(\x0cR\x06prefix\x12\x1c\n\tnamespace\x18\x02 \x01(\x0cR\tnamespace\"[\n\x13InternalKVKeysReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x18\n\x07results\x18\x02 \x03(\x0cR\x07results\"N\n\x17PinRuntimeEnvURIRequest\x12\x10\n\x03uri\x18\x01 \x01(\tR\x03uri\x12!\n\x0c\x65xpiration_s\x18\x02 \x01(\x05R\x0b\x65xpirationS\"C\n\x15PinRuntimeEnvURIReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"K\n\x11GcsPublishRequest\x12\x36\n\x0cpub_messages\x18\x01 \x03(\x0b\x32\x13.ray.rpc.PubMessageR\x0bpubMessages\"=\n\x0fGcsPublishReply\x12*\n\x06status\x18\x64 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x9d\x01\n\x18GcsSubscriberPollRequest\x12#\n\rsubscriber_id\x18\x01 \x01(\x0cR\x0csubscriberId\x12\x39\n\x19max_processed_sequence_id\x18\x02 \x01(\x03R\x16maxProcessedSequenceId\x12!\n\x0cpublisher_id\x18\x03 \x01(\x0cR\x0bpublisherId\"\x9f\x01\n\x16GcsSubscriberPollReply\x12\x36\n\x0cpub_messages\x18\x01 \x03(\x0b\x32\x13.ray.rpc.PubMessageR\x0bpubMessages\x12!\n\x0cpublisher_id\x18\x02 \x01(\x0cR\x0bpublisherId\x12*\n\x06status\x18\x64 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x92\x01\n GcsSubscriberCommandBatchRequest\x12#\n\rsubscriber_id\x18\x01 \x01(\x0cR\x0csubscriberId\x12,\n\x08\x63ommands\x18\x02 \x03(\x0b\x32\x10.ray.rpc.CommandR\x08\x63ommands\x12\x1b\n\tsender_id\x18\x03 \x01(\x0cR\x08senderId\"L\n\x1eGcsSubscriberCommandBatchReply\x12*\n\x06status\x18\x64 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x1c\n\x1aGetAllResourceUsageRequest\"\xe9\x01\n\x18GetAllResourceUsageReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12O\n\x13resource_usage_data\x18\x02 \x01(\x0b\x32\x1f.ray.rpc.ResourceUsageBatchDataR\x11resourceUsageData\x12P\n&cluster_full_of_actors_detected_by_gcs\x18\x03 \x01(\x08R clusterFullOfActorsDetectedByGcs\"9\n\tGcsStatus\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"E\n\x17\x41\x64\x64TaskEventDataRequest\x12*\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x16.ray.rpc.TaskEventDataR\x04\x64\x61ta\"C\n\x15\x41\x64\x64TaskEventDataReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\xe9\x02\n\x14GetTaskEventsRequest\x12\x19\n\x05limit\x18\x03 \x01(\x03H\x00R\x05limit\x88\x01\x01\x12\x44\n\x07\x66ilters\x18\x04 \x01(\x0b\x32%.ray.rpc.GetTaskEventsRequest.FiltersH\x01R\x07\x66ilters\x88\x01\x01\x1a\xd9\x01\n\x07\x46ilters\x12\x1a\n\x06job_id\x18\x01 \x01(\x0cH\x00R\x05jobId\x88\x01\x01\x12\x19\n\x08task_ids\x18\x02 \x03(\x0cR\x07taskIds\x12\x1e\n\x08\x61\x63tor_id\x18\x03 \x01(\x0cH\x01R\x07\x61\x63torId\x88\x01\x01\x12\x17\n\x04name\x18\x04 \x01(\tH\x02R\x04name\x88\x01\x01\x12*\n\x0e\x65xclude_driver\x18\x05 \x01(\x08H\x03R\rexcludeDriver\x88\x01\x01\x42\t\n\x07_job_idB\x0b\n\t_actor_idB\x07\n\x05_nameB\x11\n\x0f_exclude_driverB\x08\n\x06_limitB\n\n\x08_filters\"\x85\x02\n\x12GetTaskEventsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x39\n\x0e\x65vents_by_task\x18\x02 \x03(\x0b\x32\x13.ray.rpc.TaskEventsR\x0c\x65ventsByTask\x12\x44\n\x1fnum_profile_task_events_dropped\x18\x03 \x01(\x05R\x1bnumProfileTaskEventsDropped\x12\x42\n\x1enum_status_task_events_dropped\x18\x04 \x01(\x05R\x1anumStatusTaskEventsDropped*C\n\x15GcsServiceFailureType\x12\x12\n\x0eRPC_DISCONNECT\x10\x00\x12\x16\n\x12GCS_SERVER_RESTART\x10\x01\x32\x85\x03\n\x11JobInfoGcsService\x12\x36\n\x06\x41\x64\x64Job\x12\x16.ray.rpc.AddJobRequest\x1a\x14.ray.rpc.AddJobReply\x12Q\n\x0fMarkJobFinished\x12\x1f.ray.rpc.MarkJobFinishedRequest\x1a\x1d.ray.rpc.MarkJobFinishedReply\x12K\n\rGetAllJobInfo\x12\x1d.ray.rpc.GetAllJobInfoRequest\x1a\x1b.ray.rpc.GetAllJobInfoReply\x12N\n\x0eReportJobError\x12\x1e.ray.rpc.ReportJobErrorRequest\x1a\x1c.ray.rpc.ReportJobErrorReply\x12H\n\x0cGetNextJobID\x12\x1c.ray.rpc.GetNextJobIDRequest\x1a\x1a.ray.rpc.GetNextJobIDReply2\xc5\x04\n\x13\x41\x63torInfoGcsService\x12K\n\rRegisterActor\x12\x1d.ray.rpc.RegisterActorRequest\x1a\x1b.ray.rpc.RegisterActorReply\x12\x45\n\x0b\x43reateActor\x12\x1b.ray.rpc.CreateActorRequest\x1a\x19.ray.rpc.CreateActorReply\x12H\n\x0cGetActorInfo\x12\x1c.ray.rpc.GetActorInfoRequest\x1a\x1a.ray.rpc.GetActorInfoReply\x12W\n\x11GetNamedActorInfo\x12!.ray.rpc.GetNamedActorInfoRequest\x1a\x1f.ray.rpc.GetNamedActorInfoReply\x12Q\n\x0fListNamedActors\x12\x1f.ray.rpc.ListNamedActorsRequest\x1a\x1d.ray.rpc.ListNamedActorsReply\x12Q\n\x0fGetAllActorInfo\x12\x1f.ray.rpc.GetAllActorInfoRequest\x1a\x1d.ray.rpc.GetAllActorInfoReply\x12Q\n\x0fKillActorViaGcs\x12\x1f.ray.rpc.KillActorViaGcsRequest\x1a\x1d.ray.rpc.KillActorViaGcsReply2\xe5\x02\n\x14WorkerInfoGcsService\x12]\n\x13ReportWorkerFailure\x12#.ray.rpc.ReportWorkerFailureRequest\x1a!.ray.rpc.ReportWorkerFailureReply\x12K\n\rGetWorkerInfo\x12\x1d.ray.rpc.GetWorkerInfoRequest\x1a\x1b.ray.rpc.GetWorkerInfoReply\x12T\n\x10GetAllWorkerInfo\x12 .ray.rpc.GetAllWorkerInfoRequest\x1a\x1e.ray.rpc.GetAllWorkerInfoReply\x12K\n\rAddWorkerInfo\x12\x1d.ray.rpc.AddWorkerInfoRequest\x1a\x1b.ray.rpc.AddWorkerInfoReply2\xff\x04\n\x1cPlacementGroupInfoGcsService\x12`\n\x14\x43reatePlacementGroup\x12$.ray.rpc.CreatePlacementGroupRequest\x1a\".ray.rpc.CreatePlacementGroupReply\x12`\n\x14RemovePlacementGroup\x12$.ray.rpc.RemovePlacementGroupRequest\x1a\".ray.rpc.RemovePlacementGroupReply\x12W\n\x11GetPlacementGroup\x12!.ray.rpc.GetPlacementGroupRequest\x1a\x1f.ray.rpc.GetPlacementGroupReply\x12\x66\n\x16GetNamedPlacementGroup\x12&.ray.rpc.GetNamedPlacementGroupRequest\x1a$.ray.rpc.GetNamedPlacementGroupReply\x12`\n\x14GetAllPlacementGroup\x12$.ray.rpc.GetAllPlacementGroupRequest\x1a\".ray.rpc.GetAllPlacementGroupReply\x12x\n\x1cWaitPlacementGroupUntilReady\x12,.ray.rpc.WaitPlacementGroupUntilReadyRequest\x1a*.ray.rpc.WaitPlacementGroupUntilReadyReply2\xff\x03\n\x14InternalKVGcsService\x12K\n\rInternalKVGet\x12\x1d.ray.rpc.InternalKVGetRequest\x1a\x1b.ray.rpc.InternalKVGetReply\x12Z\n\x12InternalKVMultiGet\x12\".ray.rpc.InternalKVMultiGetRequest\x1a .ray.rpc.InternalKVMultiGetReply\x12K\n\rInternalKVPut\x12\x1d.ray.rpc.InternalKVPutRequest\x1a\x1b.ray.rpc.InternalKVPutReply\x12K\n\rInternalKVDel\x12\x1d.ray.rpc.InternalKVDelRequest\x1a\x1b.ray.rpc.InternalKVDelReply\x12T\n\x10InternalKVExists\x12 .ray.rpc.InternalKVExistsRequest\x1a\x1e.ray.rpc.InternalKVExistsReply\x12N\n\x0eInternalKVKeys\x12\x1e.ray.rpc.InternalKVKeysRequest\x1a\x1c.ray.rpc.InternalKVKeysReply2l\n\x14RuntimeEnvGcsService\x12T\n\x10PinRuntimeEnvURI\x12 .ray.rpc.PinRuntimeEnvURIRequest\x1a\x1e.ray.rpc.PinRuntimeEnvURIReply2\xa8\x02\n\x18InternalPubSubGcsService\x12\x42\n\nGcsPublish\x12\x1a.ray.rpc.GcsPublishRequest\x1a\x18.ray.rpc.GcsPublishReply\x12W\n\x11GcsSubscriberPoll\x12!.ray.rpc.GcsSubscriberPollRequest\x1a\x1f.ray.rpc.GcsSubscriberPollReply\x12o\n\x19GcsSubscriberCommandBatch\x12).ray.rpc.GcsSubscriberCommandBatchRequest\x1a\'.ray.rpc.GcsSubscriberCommandBatchReply2\x92\x03\n\x1aNodeResourceInfoGcsService\x12H\n\x0cGetResources\x12\x1c.ray.rpc.GetResourcesRequest\x1a\x1a.ray.rpc.GetResourcesReply\x12l\n\x18GetAllAvailableResources\x12(.ray.rpc.GetAllAvailableResourcesRequest\x1a&.ray.rpc.GetAllAvailableResourcesReply\x12]\n\x13ReportResourceUsage\x12#.ray.rpc.ReportResourceUsageRequest\x1a!.ray.rpc.ReportResourceUsageReply\x12]\n\x13GetAllResourceUsage\x12#.ray.rpc.GetAllResourceUsageRequest\x1a!.ray.rpc.GetAllResourceUsageReply2\xd6\x03\n\x12NodeInfoGcsService\x12H\n\x0cGetClusterId\x12\x1c.ray.rpc.GetClusterIdRequest\x1a\x1a.ray.rpc.GetClusterIdReply\x12H\n\x0cRegisterNode\x12\x1c.ray.rpc.RegisterNodeRequest\x1a\x1a.ray.rpc.RegisterNodeReply\x12?\n\tDrainNode\x12\x19.ray.rpc.DrainNodeRequest\x1a\x17.ray.rpc.DrainNodeReply\x12N\n\x0eGetAllNodeInfo\x12\x1e.ray.rpc.GetAllNodeInfoRequest\x1a\x1c.ray.rpc.GetAllNodeInfoReply\x12W\n\x11GetInternalConfig\x12!.ray.rpc.GetInternalConfigRequest\x1a\x1f.ray.rpc.GetInternalConfigReply\x12\x42\n\nCheckAlive\x12\x1a.ray.rpc.CheckAliveRequest\x1a\x18.ray.rpc.CheckAliveReply2\xb7\x01\n\x12TaskInfoGcsService\x12T\n\x10\x41\x64\x64TaskEventData\x12 .ray.rpc.AddTaskEventDataRequest\x1a\x1e.ray.rpc.AddTaskEventDataReply\x12K\n\rGetTaskEvents\x12\x1d.ray.rpc.GetTaskEventsRequest\x1a\x1b.ray.rpc.GetTaskEventsReplyB\x03\xf8\x01\x01\x62\x06proto3')

_GCSSERVICEFAILURETYPE = DESCRIPTOR.enum_types_by_name['GcsServiceFailureType']
GcsServiceFailureType = enum_type_wrapper.EnumTypeWrapper(_GCSSERVICEFAILURETYPE)
RPC_DISCONNECT = 0
GCS_SERVER_RESTART = 1


_ADDJOBREQUEST = DESCRIPTOR.message_types_by_name['AddJobRequest']
_ADDJOBREPLY = DESCRIPTOR.message_types_by_name['AddJobReply']
_MARKJOBFINISHEDREQUEST = DESCRIPTOR.message_types_by_name['MarkJobFinishedRequest']
_MARKJOBFINISHEDREPLY = DESCRIPTOR.message_types_by_name['MarkJobFinishedReply']
_GETALLJOBINFOREQUEST = DESCRIPTOR.message_types_by_name['GetAllJobInfoRequest']
_GETALLJOBINFOREPLY = DESCRIPTOR.message_types_by_name['GetAllJobInfoReply']
_REPORTJOBERRORREQUEST = DESCRIPTOR.message_types_by_name['ReportJobErrorRequest']
_REPORTJOBERRORREPLY = DESCRIPTOR.message_types_by_name['ReportJobErrorReply']
_GETNEXTJOBIDREQUEST = DESCRIPTOR.message_types_by_name['GetNextJobIDRequest']
_GETNEXTJOBIDREPLY = DESCRIPTOR.message_types_by_name['GetNextJobIDReply']
_GETACTORINFOREQUEST = DESCRIPTOR.message_types_by_name['GetActorInfoRequest']
_GETACTORINFOREPLY = DESCRIPTOR.message_types_by_name['GetActorInfoReply']
_GETNAMEDACTORINFOREQUEST = DESCRIPTOR.message_types_by_name['GetNamedActorInfoRequest']
_GETNAMEDACTORINFOREPLY = DESCRIPTOR.message_types_by_name['GetNamedActorInfoReply']
_LISTNAMEDACTORSREQUEST = DESCRIPTOR.message_types_by_name['ListNamedActorsRequest']
_LISTNAMEDACTORSREPLY = DESCRIPTOR.message_types_by_name['ListNamedActorsReply']
_GETALLACTORINFOREQUEST = DESCRIPTOR.message_types_by_name['GetAllActorInfoRequest']
_GETALLACTORINFOREQUEST_FILTERS = _GETALLACTORINFOREQUEST.nested_types_by_name['Filters']
_GETALLACTORINFOREPLY = DESCRIPTOR.message_types_by_name['GetAllActorInfoReply']
_KILLACTORVIAGCSREQUEST = DESCRIPTOR.message_types_by_name['KillActorViaGcsRequest']
_KILLACTORVIAGCSREPLY = DESCRIPTOR.message_types_by_name['KillActorViaGcsReply']
_GETCLUSTERIDREQUEST = DESCRIPTOR.message_types_by_name['GetClusterIdRequest']
_GETCLUSTERIDREPLY = DESCRIPTOR.message_types_by_name['GetClusterIdReply']
_REGISTERNODEREQUEST = DESCRIPTOR.message_types_by_name['RegisterNodeRequest']
_REGISTERNODEREPLY = DESCRIPTOR.message_types_by_name['RegisterNodeReply']
_GETALLNODEINFOREQUEST = DESCRIPTOR.message_types_by_name['GetAllNodeInfoRequest']
_GETALLNODEINFOREPLY = DESCRIPTOR.message_types_by_name['GetAllNodeInfoReply']
_CHECKALIVEREQUEST = DESCRIPTOR.message_types_by_name['CheckAliveRequest']
_CHECKALIVEREPLY = DESCRIPTOR.message_types_by_name['CheckAliveReply']
_GETINTERNALCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetInternalConfigRequest']
_GETINTERNALCONFIGREPLY = DESCRIPTOR.message_types_by_name['GetInternalConfigReply']
_GETRESOURCESREQUEST = DESCRIPTOR.message_types_by_name['GetResourcesRequest']
_GETRESOURCESREPLY = DESCRIPTOR.message_types_by_name['GetResourcesReply']
_GETRESOURCESREPLY_RESOURCESENTRY = _GETRESOURCESREPLY.nested_types_by_name['ResourcesEntry']
_DELETERESOURCESREPLY = DESCRIPTOR.message_types_by_name['DeleteResourcesReply']
_GETALLAVAILABLERESOURCESREQUEST = DESCRIPTOR.message_types_by_name['GetAllAvailableResourcesRequest']
_GETALLAVAILABLERESOURCESREPLY = DESCRIPTOR.message_types_by_name['GetAllAvailableResourcesReply']
_REPORTRESOURCEUSAGEREQUEST = DESCRIPTOR.message_types_by_name['ReportResourceUsageRequest']
_REPORTRESOURCEUSAGEREPLY = DESCRIPTOR.message_types_by_name['ReportResourceUsageReply']
_REPORTWORKERFAILUREREQUEST = DESCRIPTOR.message_types_by_name['ReportWorkerFailureRequest']
_REPORTWORKERFAILUREREPLY = DESCRIPTOR.message_types_by_name['ReportWorkerFailureReply']
_GETWORKERINFOREQUEST = DESCRIPTOR.message_types_by_name['GetWorkerInfoRequest']
_GETWORKERINFOREPLY = DESCRIPTOR.message_types_by_name['GetWorkerInfoReply']
_GETALLWORKERINFOREQUEST = DESCRIPTOR.message_types_by_name['GetAllWorkerInfoRequest']
_GETALLWORKERINFOREPLY = DESCRIPTOR.message_types_by_name['GetAllWorkerInfoReply']
_ADDWORKERINFOREQUEST = DESCRIPTOR.message_types_by_name['AddWorkerInfoRequest']
_ADDWORKERINFOREPLY = DESCRIPTOR.message_types_by_name['AddWorkerInfoReply']
_CREATEACTORREQUEST = DESCRIPTOR.message_types_by_name['CreateActorRequest']
_CREATEACTORREPLY = DESCRIPTOR.message_types_by_name['CreateActorReply']
_REGISTERACTORREQUEST = DESCRIPTOR.message_types_by_name['RegisterActorRequest']
_REGISTERACTORREPLY = DESCRIPTOR.message_types_by_name['RegisterActorReply']
_CREATEPLACEMENTGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreatePlacementGroupRequest']
_CREATEPLACEMENTGROUPREPLY = DESCRIPTOR.message_types_by_name['CreatePlacementGroupReply']
_REMOVEPLACEMENTGROUPREQUEST = DESCRIPTOR.message_types_by_name['RemovePlacementGroupRequest']
_REMOVEPLACEMENTGROUPREPLY = DESCRIPTOR.message_types_by_name['RemovePlacementGroupReply']
_GETPLACEMENTGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetPlacementGroupRequest']
_GETPLACEMENTGROUPREPLY = DESCRIPTOR.message_types_by_name['GetPlacementGroupReply']
_GETALLPLACEMENTGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetAllPlacementGroupRequest']
_GETALLPLACEMENTGROUPREPLY = DESCRIPTOR.message_types_by_name['GetAllPlacementGroupReply']
_WAITPLACEMENTGROUPUNTILREADYREQUEST = DESCRIPTOR.message_types_by_name['WaitPlacementGroupUntilReadyRequest']
_WAITPLACEMENTGROUPUNTILREADYREPLY = DESCRIPTOR.message_types_by_name['WaitPlacementGroupUntilReadyReply']
_GETNAMEDPLACEMENTGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetNamedPlacementGroupRequest']
_GETNAMEDPLACEMENTGROUPREPLY = DESCRIPTOR.message_types_by_name['GetNamedPlacementGroupReply']
_DRAINNODEDATA = DESCRIPTOR.message_types_by_name['DrainNodeData']
_DRAINNODEREQUEST = DESCRIPTOR.message_types_by_name['DrainNodeRequest']
_DRAINNODESTATUS = DESCRIPTOR.message_types_by_name['DrainNodeStatus']
_DRAINNODEREPLY = DESCRIPTOR.message_types_by_name['DrainNodeReply']
_INTERNALKVGETREQUEST = DESCRIPTOR.message_types_by_name['InternalKVGetRequest']
_INTERNALKVGETREPLY = DESCRIPTOR.message_types_by_name['InternalKVGetReply']
_INTERNALKVMULTIGETREQUEST = DESCRIPTOR.message_types_by_name['InternalKVMultiGetRequest']
_MAPFIELDENTRY = DESCRIPTOR.message_types_by_name['MapFieldEntry']
_INTERNALKVMULTIGETREPLY = DESCRIPTOR.message_types_by_name['InternalKVMultiGetReply']
_INTERNALKVPUTREQUEST = DESCRIPTOR.message_types_by_name['InternalKVPutRequest']
_INTERNALKVPUTREPLY = DESCRIPTOR.message_types_by_name['InternalKVPutReply']
_INTERNALKVDELREQUEST = DESCRIPTOR.message_types_by_name['InternalKVDelRequest']
_INTERNALKVDELREPLY = DESCRIPTOR.message_types_by_name['InternalKVDelReply']
_INTERNALKVEXISTSREQUEST = DESCRIPTOR.message_types_by_name['InternalKVExistsRequest']
_INTERNALKVEXISTSREPLY = DESCRIPTOR.message_types_by_name['InternalKVExistsReply']
_INTERNALKVKEYSREQUEST = DESCRIPTOR.message_types_by_name['InternalKVKeysRequest']
_INTERNALKVKEYSREPLY = DESCRIPTOR.message_types_by_name['InternalKVKeysReply']
_PINRUNTIMEENVURIREQUEST = DESCRIPTOR.message_types_by_name['PinRuntimeEnvURIRequest']
_PINRUNTIMEENVURIREPLY = DESCRIPTOR.message_types_by_name['PinRuntimeEnvURIReply']
_GCSPUBLISHREQUEST = DESCRIPTOR.message_types_by_name['GcsPublishRequest']
_GCSPUBLISHREPLY = DESCRIPTOR.message_types_by_name['GcsPublishReply']
_GCSSUBSCRIBERPOLLREQUEST = DESCRIPTOR.message_types_by_name['GcsSubscriberPollRequest']
_GCSSUBSCRIBERPOLLREPLY = DESCRIPTOR.message_types_by_name['GcsSubscriberPollReply']
_GCSSUBSCRIBERCOMMANDBATCHREQUEST = DESCRIPTOR.message_types_by_name['GcsSubscriberCommandBatchRequest']
_GCSSUBSCRIBERCOMMANDBATCHREPLY = DESCRIPTOR.message_types_by_name['GcsSubscriberCommandBatchReply']
_GETALLRESOURCEUSAGEREQUEST = DESCRIPTOR.message_types_by_name['GetAllResourceUsageRequest']
_GETALLRESOURCEUSAGEREPLY = DESCRIPTOR.message_types_by_name['GetAllResourceUsageReply']
_GCSSTATUS = DESCRIPTOR.message_types_by_name['GcsStatus']
_ADDTASKEVENTDATAREQUEST = DESCRIPTOR.message_types_by_name['AddTaskEventDataRequest']
_ADDTASKEVENTDATAREPLY = DESCRIPTOR.message_types_by_name['AddTaskEventDataReply']
_GETTASKEVENTSREQUEST = DESCRIPTOR.message_types_by_name['GetTaskEventsRequest']
_GETTASKEVENTSREQUEST_FILTERS = _GETTASKEVENTSREQUEST.nested_types_by_name['Filters']
_GETTASKEVENTSREPLY = DESCRIPTOR.message_types_by_name['GetTaskEventsReply']
AddJobRequest = _reflection.GeneratedProtocolMessageType('AddJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDJOBREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddJobRequest)
  })
_sym_db.RegisterMessage(AddJobRequest)

AddJobReply = _reflection.GeneratedProtocolMessageType('AddJobReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDJOBREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddJobReply)
  })
_sym_db.RegisterMessage(AddJobReply)

MarkJobFinishedRequest = _reflection.GeneratedProtocolMessageType('MarkJobFinishedRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKJOBFINISHEDREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.MarkJobFinishedRequest)
  })
_sym_db.RegisterMessage(MarkJobFinishedRequest)

MarkJobFinishedReply = _reflection.GeneratedProtocolMessageType('MarkJobFinishedReply', (_message.Message,), {
  'DESCRIPTOR' : _MARKJOBFINISHEDREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.MarkJobFinishedReply)
  })
_sym_db.RegisterMessage(MarkJobFinishedReply)

GetAllJobInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllJobInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLJOBINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllJobInfoRequest)
  })
_sym_db.RegisterMessage(GetAllJobInfoRequest)

GetAllJobInfoReply = _reflection.GeneratedProtocolMessageType('GetAllJobInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLJOBINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllJobInfoReply)
  })
_sym_db.RegisterMessage(GetAllJobInfoReply)

ReportJobErrorRequest = _reflection.GeneratedProtocolMessageType('ReportJobErrorRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTJOBERRORREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportJobErrorRequest)
  })
_sym_db.RegisterMessage(ReportJobErrorRequest)

ReportJobErrorReply = _reflection.GeneratedProtocolMessageType('ReportJobErrorReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTJOBERRORREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportJobErrorReply)
  })
_sym_db.RegisterMessage(ReportJobErrorReply)

GetNextJobIDRequest = _reflection.GeneratedProtocolMessageType('GetNextJobIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNEXTJOBIDREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNextJobIDRequest)
  })
_sym_db.RegisterMessage(GetNextJobIDRequest)

GetNextJobIDReply = _reflection.GeneratedProtocolMessageType('GetNextJobIDReply', (_message.Message,), {
  'DESCRIPTOR' : _GETNEXTJOBIDREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNextJobIDReply)
  })
_sym_db.RegisterMessage(GetNextJobIDReply)

GetActorInfoRequest = _reflection.GeneratedProtocolMessageType('GetActorInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetActorInfoRequest)
  })
_sym_db.RegisterMessage(GetActorInfoRequest)

GetActorInfoReply = _reflection.GeneratedProtocolMessageType('GetActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetActorInfoReply)
  })
_sym_db.RegisterMessage(GetActorInfoReply)

GetNamedActorInfoRequest = _reflection.GeneratedProtocolMessageType('GetNamedActorInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMEDACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNamedActorInfoRequest)
  })
_sym_db.RegisterMessage(GetNamedActorInfoRequest)

GetNamedActorInfoReply = _reflection.GeneratedProtocolMessageType('GetNamedActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMEDACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNamedActorInfoReply)
  })
_sym_db.RegisterMessage(GetNamedActorInfoReply)

ListNamedActorsRequest = _reflection.GeneratedProtocolMessageType('ListNamedActorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNAMEDACTORSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ListNamedActorsRequest)
  })
_sym_db.RegisterMessage(ListNamedActorsRequest)

ListNamedActorsReply = _reflection.GeneratedProtocolMessageType('ListNamedActorsReply', (_message.Message,), {
  'DESCRIPTOR' : _LISTNAMEDACTORSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ListNamedActorsReply)
  })
_sym_db.RegisterMessage(ListNamedActorsReply)

GetAllActorInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllActorInfoRequest', (_message.Message,), {

  'Filters' : _reflection.GeneratedProtocolMessageType('Filters', (_message.Message,), {
    'DESCRIPTOR' : _GETALLACTORINFOREQUEST_FILTERS,
    '__module__' : 'src.ray.protobuf.gcs_service_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.GetAllActorInfoRequest.Filters)
    })
  ,
  'DESCRIPTOR' : _GETALLACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllActorInfoRequest)
  })
_sym_db.RegisterMessage(GetAllActorInfoRequest)
_sym_db.RegisterMessage(GetAllActorInfoRequest.Filters)

GetAllActorInfoReply = _reflection.GeneratedProtocolMessageType('GetAllActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllActorInfoReply)
  })
_sym_db.RegisterMessage(GetAllActorInfoReply)

KillActorViaGcsRequest = _reflection.GeneratedProtocolMessageType('KillActorViaGcsRequest', (_message.Message,), {
  'DESCRIPTOR' : _KILLACTORVIAGCSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KillActorViaGcsRequest)
  })
_sym_db.RegisterMessage(KillActorViaGcsRequest)

KillActorViaGcsReply = _reflection.GeneratedProtocolMessageType('KillActorViaGcsReply', (_message.Message,), {
  'DESCRIPTOR' : _KILLACTORVIAGCSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KillActorViaGcsReply)
  })
_sym_db.RegisterMessage(KillActorViaGcsReply)

GetClusterIdRequest = _reflection.GeneratedProtocolMessageType('GetClusterIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERIDREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetClusterIdRequest)
  })
_sym_db.RegisterMessage(GetClusterIdRequest)

GetClusterIdReply = _reflection.GeneratedProtocolMessageType('GetClusterIdReply', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERIDREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetClusterIdReply)
  })
_sym_db.RegisterMessage(GetClusterIdReply)

RegisterNodeRequest = _reflection.GeneratedProtocolMessageType('RegisterNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERNODEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterNodeRequest)
  })
_sym_db.RegisterMessage(RegisterNodeRequest)

RegisterNodeReply = _reflection.GeneratedProtocolMessageType('RegisterNodeReply', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERNODEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterNodeReply)
  })
_sym_db.RegisterMessage(RegisterNodeReply)

GetAllNodeInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllNodeInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLNODEINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllNodeInfoRequest)
  })
_sym_db.RegisterMessage(GetAllNodeInfoRequest)

GetAllNodeInfoReply = _reflection.GeneratedProtocolMessageType('GetAllNodeInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLNODEINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllNodeInfoReply)
  })
_sym_db.RegisterMessage(GetAllNodeInfoReply)

CheckAliveRequest = _reflection.GeneratedProtocolMessageType('CheckAliveRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKALIVEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CheckAliveRequest)
  })
_sym_db.RegisterMessage(CheckAliveRequest)

CheckAliveReply = _reflection.GeneratedProtocolMessageType('CheckAliveReply', (_message.Message,), {
  'DESCRIPTOR' : _CHECKALIVEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CheckAliveReply)
  })
_sym_db.RegisterMessage(CheckAliveReply)

GetInternalConfigRequest = _reflection.GeneratedProtocolMessageType('GetInternalConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERNALCONFIGREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetInternalConfigRequest)
  })
_sym_db.RegisterMessage(GetInternalConfigRequest)

GetInternalConfigReply = _reflection.GeneratedProtocolMessageType('GetInternalConfigReply', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERNALCONFIGREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetInternalConfigReply)
  })
_sym_db.RegisterMessage(GetInternalConfigReply)

GetResourcesRequest = _reflection.GeneratedProtocolMessageType('GetResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCESREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetResourcesRequest)
  })
_sym_db.RegisterMessage(GetResourcesRequest)

GetResourcesReply = _reflection.GeneratedProtocolMessageType('GetResourcesReply', (_message.Message,), {

  'ResourcesEntry' : _reflection.GeneratedProtocolMessageType('ResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETRESOURCESREPLY_RESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.gcs_service_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.GetResourcesReply.ResourcesEntry)
    })
  ,
  'DESCRIPTOR' : _GETRESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetResourcesReply)
  })
_sym_db.RegisterMessage(GetResourcesReply)
_sym_db.RegisterMessage(GetResourcesReply.ResourcesEntry)

DeleteResourcesReply = _reflection.GeneratedProtocolMessageType('DeleteResourcesReply', (_message.Message,), {
  'DESCRIPTOR' : _DELETERESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DeleteResourcesReply)
  })
_sym_db.RegisterMessage(DeleteResourcesReply)

GetAllAvailableResourcesRequest = _reflection.GeneratedProtocolMessageType('GetAllAvailableResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLAVAILABLERESOURCESREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllAvailableResourcesRequest)
  })
_sym_db.RegisterMessage(GetAllAvailableResourcesRequest)

GetAllAvailableResourcesReply = _reflection.GeneratedProtocolMessageType('GetAllAvailableResourcesReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLAVAILABLERESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllAvailableResourcesReply)
  })
_sym_db.RegisterMessage(GetAllAvailableResourcesReply)

ReportResourceUsageRequest = _reflection.GeneratedProtocolMessageType('ReportResourceUsageRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTRESOURCEUSAGEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportResourceUsageRequest)
  })
_sym_db.RegisterMessage(ReportResourceUsageRequest)

ReportResourceUsageReply = _reflection.GeneratedProtocolMessageType('ReportResourceUsageReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTRESOURCEUSAGEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportResourceUsageReply)
  })
_sym_db.RegisterMessage(ReportResourceUsageReply)

ReportWorkerFailureRequest = _reflection.GeneratedProtocolMessageType('ReportWorkerFailureRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTWORKERFAILUREREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportWorkerFailureRequest)
  })
_sym_db.RegisterMessage(ReportWorkerFailureRequest)

ReportWorkerFailureReply = _reflection.GeneratedProtocolMessageType('ReportWorkerFailureReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTWORKERFAILUREREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportWorkerFailureReply)
  })
_sym_db.RegisterMessage(ReportWorkerFailureReply)

GetWorkerInfoRequest = _reflection.GeneratedProtocolMessageType('GetWorkerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKERINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetWorkerInfoRequest)
  })
_sym_db.RegisterMessage(GetWorkerInfoRequest)

GetWorkerInfoReply = _reflection.GeneratedProtocolMessageType('GetWorkerInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKERINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetWorkerInfoReply)
  })
_sym_db.RegisterMessage(GetWorkerInfoReply)

GetAllWorkerInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllWorkerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLWORKERINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllWorkerInfoRequest)
  })
_sym_db.RegisterMessage(GetAllWorkerInfoRequest)

GetAllWorkerInfoReply = _reflection.GeneratedProtocolMessageType('GetAllWorkerInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLWORKERINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllWorkerInfoReply)
  })
_sym_db.RegisterMessage(GetAllWorkerInfoReply)

AddWorkerInfoRequest = _reflection.GeneratedProtocolMessageType('AddWorkerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDWORKERINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddWorkerInfoRequest)
  })
_sym_db.RegisterMessage(AddWorkerInfoRequest)

AddWorkerInfoReply = _reflection.GeneratedProtocolMessageType('AddWorkerInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDWORKERINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddWorkerInfoReply)
  })
_sym_db.RegisterMessage(AddWorkerInfoReply)

CreateActorRequest = _reflection.GeneratedProtocolMessageType('CreateActorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACTORREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreateActorRequest)
  })
_sym_db.RegisterMessage(CreateActorRequest)

CreateActorReply = _reflection.GeneratedProtocolMessageType('CreateActorReply', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACTORREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreateActorReply)
  })
_sym_db.RegisterMessage(CreateActorReply)

RegisterActorRequest = _reflection.GeneratedProtocolMessageType('RegisterActorRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERACTORREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterActorRequest)
  })
_sym_db.RegisterMessage(RegisterActorRequest)

RegisterActorReply = _reflection.GeneratedProtocolMessageType('RegisterActorReply', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERACTORREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterActorReply)
  })
_sym_db.RegisterMessage(RegisterActorReply)

CreatePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('CreatePlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreatePlacementGroupRequest)
  })
_sym_db.RegisterMessage(CreatePlacementGroupRequest)

CreatePlacementGroupReply = _reflection.GeneratedProtocolMessageType('CreatePlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreatePlacementGroupReply)
  })
_sym_db.RegisterMessage(CreatePlacementGroupReply)

RemovePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('RemovePlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RemovePlacementGroupRequest)
  })
_sym_db.RegisterMessage(RemovePlacementGroupRequest)

RemovePlacementGroupReply = _reflection.GeneratedProtocolMessageType('RemovePlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RemovePlacementGroupReply)
  })
_sym_db.RegisterMessage(RemovePlacementGroupReply)

GetPlacementGroupRequest = _reflection.GeneratedProtocolMessageType('GetPlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetPlacementGroupRequest)
  })
_sym_db.RegisterMessage(GetPlacementGroupRequest)

GetPlacementGroupReply = _reflection.GeneratedProtocolMessageType('GetPlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _GETPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetPlacementGroupReply)
  })
_sym_db.RegisterMessage(GetPlacementGroupReply)

GetAllPlacementGroupRequest = _reflection.GeneratedProtocolMessageType('GetAllPlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllPlacementGroupRequest)
  })
_sym_db.RegisterMessage(GetAllPlacementGroupRequest)

GetAllPlacementGroupReply = _reflection.GeneratedProtocolMessageType('GetAllPlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllPlacementGroupReply)
  })
_sym_db.RegisterMessage(GetAllPlacementGroupReply)

WaitPlacementGroupUntilReadyRequest = _reflection.GeneratedProtocolMessageType('WaitPlacementGroupUntilReadyRequest', (_message.Message,), {
  'DESCRIPTOR' : _WAITPLACEMENTGROUPUNTILREADYREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WaitPlacementGroupUntilReadyRequest)
  })
_sym_db.RegisterMessage(WaitPlacementGroupUntilReadyRequest)

WaitPlacementGroupUntilReadyReply = _reflection.GeneratedProtocolMessageType('WaitPlacementGroupUntilReadyReply', (_message.Message,), {
  'DESCRIPTOR' : _WAITPLACEMENTGROUPUNTILREADYREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WaitPlacementGroupUntilReadyReply)
  })
_sym_db.RegisterMessage(WaitPlacementGroupUntilReadyReply)

GetNamedPlacementGroupRequest = _reflection.GeneratedProtocolMessageType('GetNamedPlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMEDPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNamedPlacementGroupRequest)
  })
_sym_db.RegisterMessage(GetNamedPlacementGroupRequest)

GetNamedPlacementGroupReply = _reflection.GeneratedProtocolMessageType('GetNamedPlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMEDPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNamedPlacementGroupReply)
  })
_sym_db.RegisterMessage(GetNamedPlacementGroupReply)

DrainNodeData = _reflection.GeneratedProtocolMessageType('DrainNodeData', (_message.Message,), {
  'DESCRIPTOR' : _DRAINNODEDATA,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DrainNodeData)
  })
_sym_db.RegisterMessage(DrainNodeData)

DrainNodeRequest = _reflection.GeneratedProtocolMessageType('DrainNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DRAINNODEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DrainNodeRequest)
  })
_sym_db.RegisterMessage(DrainNodeRequest)

DrainNodeStatus = _reflection.GeneratedProtocolMessageType('DrainNodeStatus', (_message.Message,), {
  'DESCRIPTOR' : _DRAINNODESTATUS,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DrainNodeStatus)
  })
_sym_db.RegisterMessage(DrainNodeStatus)

DrainNodeReply = _reflection.GeneratedProtocolMessageType('DrainNodeReply', (_message.Message,), {
  'DESCRIPTOR' : _DRAINNODEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DrainNodeReply)
  })
_sym_db.RegisterMessage(DrainNodeReply)

InternalKVGetRequest = _reflection.GeneratedProtocolMessageType('InternalKVGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVGETREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVGetRequest)
  })
_sym_db.RegisterMessage(InternalKVGetRequest)

InternalKVGetReply = _reflection.GeneratedProtocolMessageType('InternalKVGetReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVGETREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVGetReply)
  })
_sym_db.RegisterMessage(InternalKVGetReply)

InternalKVMultiGetRequest = _reflection.GeneratedProtocolMessageType('InternalKVMultiGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVMULTIGETREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVMultiGetRequest)
  })
_sym_db.RegisterMessage(InternalKVMultiGetRequest)

MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), {
  'DESCRIPTOR' : _MAPFIELDENTRY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.MapFieldEntry)
  })
_sym_db.RegisterMessage(MapFieldEntry)

InternalKVMultiGetReply = _reflection.GeneratedProtocolMessageType('InternalKVMultiGetReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVMULTIGETREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVMultiGetReply)
  })
_sym_db.RegisterMessage(InternalKVMultiGetReply)

InternalKVPutRequest = _reflection.GeneratedProtocolMessageType('InternalKVPutRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVPUTREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVPutRequest)
  })
_sym_db.RegisterMessage(InternalKVPutRequest)

InternalKVPutReply = _reflection.GeneratedProtocolMessageType('InternalKVPutReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVPUTREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVPutReply)
  })
_sym_db.RegisterMessage(InternalKVPutReply)

InternalKVDelRequest = _reflection.GeneratedProtocolMessageType('InternalKVDelRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVDELREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVDelRequest)
  })
_sym_db.RegisterMessage(InternalKVDelRequest)

InternalKVDelReply = _reflection.GeneratedProtocolMessageType('InternalKVDelReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVDELREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVDelReply)
  })
_sym_db.RegisterMessage(InternalKVDelReply)

InternalKVExistsRequest = _reflection.GeneratedProtocolMessageType('InternalKVExistsRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVEXISTSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVExistsRequest)
  })
_sym_db.RegisterMessage(InternalKVExistsRequest)

InternalKVExistsReply = _reflection.GeneratedProtocolMessageType('InternalKVExistsReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVEXISTSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVExistsReply)
  })
_sym_db.RegisterMessage(InternalKVExistsReply)

InternalKVKeysRequest = _reflection.GeneratedProtocolMessageType('InternalKVKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVKEYSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVKeysRequest)
  })
_sym_db.RegisterMessage(InternalKVKeysRequest)

InternalKVKeysReply = _reflection.GeneratedProtocolMessageType('InternalKVKeysReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVKEYSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVKeysReply)
  })
_sym_db.RegisterMessage(InternalKVKeysReply)

PinRuntimeEnvURIRequest = _reflection.GeneratedProtocolMessageType('PinRuntimeEnvURIRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINRUNTIMEENVURIREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PinRuntimeEnvURIRequest)
  })
_sym_db.RegisterMessage(PinRuntimeEnvURIRequest)

PinRuntimeEnvURIReply = _reflection.GeneratedProtocolMessageType('PinRuntimeEnvURIReply', (_message.Message,), {
  'DESCRIPTOR' : _PINRUNTIMEENVURIREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PinRuntimeEnvURIReply)
  })
_sym_db.RegisterMessage(PinRuntimeEnvURIReply)

GcsPublishRequest = _reflection.GeneratedProtocolMessageType('GcsPublishRequest', (_message.Message,), {
  'DESCRIPTOR' : _GCSPUBLISHREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsPublishRequest)
  })
_sym_db.RegisterMessage(GcsPublishRequest)

GcsPublishReply = _reflection.GeneratedProtocolMessageType('GcsPublishReply', (_message.Message,), {
  'DESCRIPTOR' : _GCSPUBLISHREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsPublishReply)
  })
_sym_db.RegisterMessage(GcsPublishReply)

GcsSubscriberPollRequest = _reflection.GeneratedProtocolMessageType('GcsSubscriberPollRequest', (_message.Message,), {
  'DESCRIPTOR' : _GCSSUBSCRIBERPOLLREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsSubscriberPollRequest)
  })
_sym_db.RegisterMessage(GcsSubscriberPollRequest)

GcsSubscriberPollReply = _reflection.GeneratedProtocolMessageType('GcsSubscriberPollReply', (_message.Message,), {
  'DESCRIPTOR' : _GCSSUBSCRIBERPOLLREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsSubscriberPollReply)
  })
_sym_db.RegisterMessage(GcsSubscriberPollReply)

GcsSubscriberCommandBatchRequest = _reflection.GeneratedProtocolMessageType('GcsSubscriberCommandBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _GCSSUBSCRIBERCOMMANDBATCHREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsSubscriberCommandBatchRequest)
  })
_sym_db.RegisterMessage(GcsSubscriberCommandBatchRequest)

GcsSubscriberCommandBatchReply = _reflection.GeneratedProtocolMessageType('GcsSubscriberCommandBatchReply', (_message.Message,), {
  'DESCRIPTOR' : _GCSSUBSCRIBERCOMMANDBATCHREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsSubscriberCommandBatchReply)
  })
_sym_db.RegisterMessage(GcsSubscriberCommandBatchReply)

GetAllResourceUsageRequest = _reflection.GeneratedProtocolMessageType('GetAllResourceUsageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLRESOURCEUSAGEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllResourceUsageRequest)
  })
_sym_db.RegisterMessage(GetAllResourceUsageRequest)

GetAllResourceUsageReply = _reflection.GeneratedProtocolMessageType('GetAllResourceUsageReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLRESOURCEUSAGEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllResourceUsageReply)
  })
_sym_db.RegisterMessage(GetAllResourceUsageReply)

GcsStatus = _reflection.GeneratedProtocolMessageType('GcsStatus', (_message.Message,), {
  'DESCRIPTOR' : _GCSSTATUS,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsStatus)
  })
_sym_db.RegisterMessage(GcsStatus)

AddTaskEventDataRequest = _reflection.GeneratedProtocolMessageType('AddTaskEventDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTASKEVENTDATAREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddTaskEventDataRequest)
  })
_sym_db.RegisterMessage(AddTaskEventDataRequest)

AddTaskEventDataReply = _reflection.GeneratedProtocolMessageType('AddTaskEventDataReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDTASKEVENTDATAREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddTaskEventDataReply)
  })
_sym_db.RegisterMessage(AddTaskEventDataReply)

GetTaskEventsRequest = _reflection.GeneratedProtocolMessageType('GetTaskEventsRequest', (_message.Message,), {

  'Filters' : _reflection.GeneratedProtocolMessageType('Filters', (_message.Message,), {
    'DESCRIPTOR' : _GETTASKEVENTSREQUEST_FILTERS,
    '__module__' : 'src.ray.protobuf.gcs_service_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskEventsRequest.Filters)
    })
  ,
  'DESCRIPTOR' : _GETTASKEVENTSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskEventsRequest)
  })
_sym_db.RegisterMessage(GetTaskEventsRequest)
_sym_db.RegisterMessage(GetTaskEventsRequest.Filters)

GetTaskEventsReply = _reflection.GeneratedProtocolMessageType('GetTaskEventsReply', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKEVENTSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskEventsReply)
  })
_sym_db.RegisterMessage(GetTaskEventsReply)

_JOBINFOGCSSERVICE = DESCRIPTOR.services_by_name['JobInfoGcsService']
_ACTORINFOGCSSERVICE = DESCRIPTOR.services_by_name['ActorInfoGcsService']
_WORKERINFOGCSSERVICE = DESCRIPTOR.services_by_name['WorkerInfoGcsService']
_PLACEMENTGROUPINFOGCSSERVICE = DESCRIPTOR.services_by_name['PlacementGroupInfoGcsService']
_INTERNALKVGCSSERVICE = DESCRIPTOR.services_by_name['InternalKVGcsService']
_RUNTIMEENVGCSSERVICE = DESCRIPTOR.services_by_name['RuntimeEnvGcsService']
_INTERNALPUBSUBGCSSERVICE = DESCRIPTOR.services_by_name['InternalPubSubGcsService']
_NODERESOURCEINFOGCSSERVICE = DESCRIPTOR.services_by_name['NodeResourceInfoGcsService']
_NODEINFOGCSSERVICE = DESCRIPTOR.services_by_name['NodeInfoGcsService']
_TASKINFOGCSSERVICE = DESCRIPTOR.services_by_name['TaskInfoGcsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _GETRESOURCESREPLY_RESOURCESENTRY._options = None
  _GETRESOURCESREPLY_RESOURCESENTRY._serialized_options = b'8\001'
  _GCSSERVICEFAILURETYPE._serialized_start=9551
  _GCSSERVICEFAILURETYPE._serialized_end=9618
  _ADDJOBREQUEST._serialized_start=137
  _ADDJOBREQUEST._serialized_end=195
  _ADDJOBREPLY._serialized_start=197
  _ADDJOBREPLY._serialized_end=254
  _MARKJOBFINISHEDREQUEST._serialized_start=256
  _MARKJOBFINISHEDREQUEST._serialized_end=303
  _MARKJOBFINISHEDREPLY._serialized_start=305
  _MARKJOBFINISHEDREPLY._serialized_end=371
  _GETALLJOBINFOREQUEST._serialized_start=373
  _GETALLJOBINFOREQUEST._serialized_end=432
  _GETALLJOBINFOREPLY._serialized_start=434
  _GETALLJOBINFOREPLY._serialized_end=557
  _REPORTJOBERRORREQUEST._serialized_start=559
  _REPORTJOBERRORREQUEST._serialized_end=636
  _REPORTJOBERRORREPLY._serialized_start=638
  _REPORTJOBERRORREPLY._serialized_end=703
  _GETNEXTJOBIDREQUEST._serialized_start=705
  _GETNEXTJOBIDREQUEST._serialized_end=726
  _GETNEXTJOBIDREPLY._serialized_start=728
  _GETNEXTJOBIDREPLY._serialized_end=814
  _GETACTORINFOREQUEST._serialized_start=816
  _GETACTORINFOREQUEST._serialized_end=884
  _GETACTORINFOREPLY._serialized_start=887
  _GETACTORINFOREPLY._serialized_end=1017
  _GETNAMEDACTORINFOREQUEST._serialized_start=1019
  _GETNAMEDACTORINFOREQUEST._serialized_end=1102
  _GETNAMEDACTORINFOREPLY._serialized_start=1105
  _GETNAMEDACTORINFOREPLY._serialized_end=1288
  _LISTNAMEDACTORSREQUEST._serialized_start=1290
  _LISTNAMEDACTORSREQUEST._serialized_end=1390
  _LISTNAMEDACTORSREPLY._serialized_start=1393
  _LISTNAMEDACTORSREPLY._serialized_end=1528
  _GETALLACTORINFOREQUEST._serialized_start=1531
  _GETALLACTORINFOREQUEST._serialized_end=1883
  _GETALLACTORINFOREQUEST_FILTERS._serialized_start=1695
  _GETALLACTORINFOREQUEST_FILTERS._serialized_end=1861
  _GETALLACTORINFOREPLY._serialized_start=1886
  _GETALLACTORINFOREPLY._serialized_end=2076
  _KILLACTORVIAGCSREQUEST._serialized_start=2078
  _KILLACTORVIAGCSREQUEST._serialized_end=2191
  _KILLACTORVIAGCSREPLY._serialized_start=2193
  _KILLACTORVIAGCSREPLY._serialized_end=2259
  _GETCLUSTERIDREQUEST._serialized_start=2261
  _GETCLUSTERIDREQUEST._serialized_end=2282
  _GETCLUSTERIDREPLY._serialized_start=2284
  _GETCLUSTERIDREPLY._serialized_end=2378
  _REGISTERNODEREQUEST._serialized_start=2380
  _REGISTERNODEREQUEST._serialized_end=2452
  _REGISTERNODEREPLY._serialized_start=2454
  _REGISTERNODEREPLY._serialized_end=2517
  _GETALLNODEINFOREQUEST._serialized_start=2519
  _GETALLNODEINFOREQUEST._serialized_end=2542
  _GETALLNODEINFOREPLY._serialized_start=2544
  _GETALLNODEINFOREPLY._serialized_end=2669
  _CHECKALIVEREQUEST._serialized_start=2671
  _CHECKALIVEREQUEST._serialized_end=2729
  _CHECKALIVEREPLY._serialized_start=2732
  _CHECKALIVEREPLY._serialized_end=2861
  _GETINTERNALCONFIGREQUEST._serialized_start=2863
  _GETINTERNALCONFIGREQUEST._serialized_end=2889
  _GETINTERNALCONFIGREPLY._serialized_start=2891
  _GETINTERNALCONFIGREPLY._serialized_end=2983
  _GETRESOURCESREQUEST._serialized_start=2985
  _GETRESOURCESREQUEST._serialized_end=3031
  _GETRESOURCESREPLY._serialized_start=3034
  _GETRESOURCESREPLY._serialized_end=3260
  _GETRESOURCESREPLY_RESOURCESENTRY._serialized_start=3172
  _GETRESOURCESREPLY_RESOURCESENTRY._serialized_end=3260
  _DELETERESOURCESREPLY._serialized_start=3262
  _DELETERESOURCESREPLY._serialized_end=3328
  _GETALLAVAILABLERESOURCESREQUEST._serialized_start=3330
  _GETALLAVAILABLERESOURCESREQUEST._serialized_end=3363
  _GETALLAVAILABLERESOURCESREPLY._serialized_start=3366
  _GETALLAVAILABLERESOURCESREPLY._serialized_end=3509
  _REPORTRESOURCEUSAGEREQUEST._serialized_start=3511
  _REPORTRESOURCEUSAGEREQUEST._serialized_end=3593
  _REPORTRESOURCEUSAGEREPLY._serialized_start=3595
  _REPORTRESOURCEUSAGEREPLY._serialized_end=3665
  _REPORTWORKERFAILUREREQUEST._serialized_start=3667
  _REPORTWORKERFAILUREREQUEST._serialized_end=3760
  _REPORTWORKERFAILUREREPLY._serialized_start=3762
  _REPORTWORKERFAILUREREPLY._serialized_end=3832
  _GETWORKERINFOREQUEST._serialized_start=3834
  _GETWORKERINFOREQUEST._serialized_end=3885
  _GETWORKERINFOREPLY._serialized_start=3888
  _GETWORKERINFOREPLY._serialized_end=4022
  _GETALLWORKERINFOREQUEST._serialized_start=4024
  _GETALLWORKERINFOREQUEST._serialized_end=4086
  _GETALLWORKERINFOREPLY._serialized_start=4089
  _GETALLWORKERINFOREPLY._serialized_end=4248
  _ADDWORKERINFOREQUEST._serialized_start=4250
  _ADDWORKERINFOREQUEST._serialized_end=4331
  _ADDWORKERINFOREPLY._serialized_start=4333
  _ADDWORKERINFOREPLY._serialized_end=4397
  _CREATEACTORREQUEST._serialized_start=4399
  _CREATEACTORREQUEST._serialized_end=4467
  _CREATEACTORREPLY._serialized_start=4470
  _CREATEACTORREPLY._serialized_end=4735
  _REGISTERACTORREQUEST._serialized_start=4737
  _REGISTERACTORREQUEST._serialized_end=4807
  _REGISTERACTORREPLY._serialized_start=4809
  _REGISTERACTORREPLY._serialized_end=4873
  _CREATEPLACEMENTGROUPREQUEST._serialized_start=4875
  _CREATEPLACEMENTGROUPREQUEST._serialized_end=4983
  _CREATEPLACEMENTGROUPREPLY._serialized_start=4985
  _CREATEPLACEMENTGROUPREPLY._serialized_end=5056
  _REMOVEPLACEMENTGROUPREQUEST._serialized_start=5058
  _REMOVEPLACEMENTGROUPREQUEST._serialized_end=5133
  _REMOVEPLACEMENTGROUPREPLY._serialized_start=5135
  _REMOVEPLACEMENTGROUPREPLY._serialized_end=5206
  _GETPLACEMENTGROUPREQUEST._serialized_start=5208
  _GETPLACEMENTGROUPREQUEST._serialized_end=5280
  _GETPLACEMENTGROUPREPLY._serialized_start=5283
  _GETPLACEMENTGROUPREPLY._serialized_end=5446
  _GETALLPLACEMENTGROUPREQUEST._serialized_start=5448
  _GETALLPLACEMENTGROUPREQUEST._serialized_end=5514
  _GETALLPLACEMENTGROUPREPLY._serialized_start=5517
  _GETALLPLACEMENTGROUPREPLY._serialized_end=5705
  _WAITPLACEMENTGROUPUNTILREADYREQUEST._serialized_start=5707
  _WAITPLACEMENTGROUPUNTILREADYREQUEST._serialized_end=5790
  _WAITPLACEMENTGROUPUNTILREADYREPLY._serialized_start=5792
  _WAITPLACEMENTGROUPUNTILREADYREPLY._serialized_end=5871
  _GETNAMEDPLACEMENTGROUPREQUEST._serialized_start=5873
  _GETNAMEDPLACEMENTGROUPREQUEST._serialized_end=5961
  _GETNAMEDPLACEMENTGROUPREPLY._serialized_start=5964
  _GETNAMEDPLACEMENTGROUPREPLY._serialized_end=6132
  _DRAINNODEDATA._serialized_start=6134
  _DRAINNODEDATA._serialized_end=6174
  _DRAINNODEREQUEST._serialized_start=6176
  _DRAINNODEREQUEST._serialized_end=6258
  _DRAINNODESTATUS._serialized_start=6260
  _DRAINNODESTATUS._serialized_end=6302
  _DRAINNODEREPLY._serialized_start=6305
  _DRAINNODEREPLY._serialized_end=6435
  _INTERNALKVGETREQUEST._serialized_start=6437
  _INTERNALKVGETREQUEST._serialized_end=6507
  _INTERNALKVGETREPLY._serialized_start=6509
  _INTERNALKVGETREPLY._serialized_end=6595
  _INTERNALKVMULTIGETREQUEST._serialized_start=6597
  _INTERNALKVMULTIGETREQUEST._serialized_end=6674
  _MAPFIELDENTRY._serialized_start=6676
  _MAPFIELDENTRY._serialized_end=6731
  _INTERNALKVMULTIGETREPLY._serialized_start=6733
  _INTERNALKVMULTIGETREPLY._serialized_end=6852
  _INTERNALKVPUTREQUEST._serialized_start=6854
  _INTERNALKVPUTREQUEST._serialized_end=6976
  _INTERNALKVPUTREPLY._serialized_start=6978
  _INTERNALKVPUTREPLY._serialized_end=7071
  _INTERNALKVDELREQUEST._serialized_start=7073
  _INTERNALKVDELREQUEST._serialized_end=7179
  _INTERNALKVDELREPLY._serialized_start=7181
  _INTERNALKVDELREPLY._serialized_end=7278
  _INTERNALKVEXISTSREQUEST._serialized_start=7280
  _INTERNALKVEXISTSREQUEST._serialized_end=7353
  _INTERNALKVEXISTSREPLY._serialized_start=7355
  _INTERNALKVEXISTSREPLY._serialized_end=7446
  _INTERNALKVKEYSREQUEST._serialized_start=7448
  _INTERNALKVKEYSREQUEST._serialized_end=7525
  _INTERNALKVKEYSREPLY._serialized_start=7527
  _INTERNALKVKEYSREPLY._serialized_end=7618
  _PINRUNTIMEENVURIREQUEST._serialized_start=7620
  _PINRUNTIMEENVURIREQUEST._serialized_end=7698
  _PINRUNTIMEENVURIREPLY._serialized_start=7700
  _PINRUNTIMEENVURIREPLY._serialized_end=7767
  _GCSPUBLISHREQUEST._serialized_start=7769
  _GCSPUBLISHREQUEST._serialized_end=7844
  _GCSPUBLISHREPLY._serialized_start=7846
  _GCSPUBLISHREPLY._serialized_end=7907
  _GCSSUBSCRIBERPOLLREQUEST._serialized_start=7910
  _GCSSUBSCRIBERPOLLREQUEST._serialized_end=8067
  _GCSSUBSCRIBERPOLLREPLY._serialized_start=8070
  _GCSSUBSCRIBERPOLLREPLY._serialized_end=8229
  _GCSSUBSCRIBERCOMMANDBATCHREQUEST._serialized_start=8232
  _GCSSUBSCRIBERCOMMANDBATCHREQUEST._serialized_end=8378
  _GCSSUBSCRIBERCOMMANDBATCHREPLY._serialized_start=8380
  _GCSSUBSCRIBERCOMMANDBATCHREPLY._serialized_end=8456
  _GETALLRESOURCEUSAGEREQUEST._serialized_start=8458
  _GETALLRESOURCEUSAGEREQUEST._serialized_end=8486
  _GETALLRESOURCEUSAGEREPLY._serialized_start=8489
  _GETALLRESOURCEUSAGEREPLY._serialized_end=8722
  _GCSSTATUS._serialized_start=8724
  _GCSSTATUS._serialized_end=8781
  _ADDTASKEVENTDATAREQUEST._serialized_start=8783
  _ADDTASKEVENTDATAREQUEST._serialized_end=8852
  _ADDTASKEVENTDATAREPLY._serialized_start=8854
  _ADDTASKEVENTDATAREPLY._serialized_end=8921
  _GETTASKEVENTSREQUEST._serialized_start=8924
  _GETTASKEVENTSREQUEST._serialized_end=9285
  _GETTASKEVENTSREQUEST_FILTERS._serialized_start=9046
  _GETTASKEVENTSREQUEST_FILTERS._serialized_end=9263
  _GETTASKEVENTSREPLY._serialized_start=9288
  _GETTASKEVENTSREPLY._serialized_end=9549
  _JOBINFOGCSSERVICE._serialized_start=9621
  _JOBINFOGCSSERVICE._serialized_end=10010
  _ACTORINFOGCSSERVICE._serialized_start=10013
  _ACTORINFOGCSSERVICE._serialized_end=10594
  _WORKERINFOGCSSERVICE._serialized_start=10597
  _WORKERINFOGCSSERVICE._serialized_end=10954
  _PLACEMENTGROUPINFOGCSSERVICE._serialized_start=10957
  _PLACEMENTGROUPINFOGCSSERVICE._serialized_end=11596
  _INTERNALKVGCSSERVICE._serialized_start=11599
  _INTERNALKVGCSSERVICE._serialized_end=12110
  _RUNTIMEENVGCSSERVICE._serialized_start=12112
  _RUNTIMEENVGCSSERVICE._serialized_end=12220
  _INTERNALPUBSUBGCSSERVICE._serialized_start=12223
  _INTERNALPUBSUBGCSSERVICE._serialized_end=12519
  _NODERESOURCEINFOGCSSERVICE._serialized_start=12522
  _NODERESOURCEINFOGCSSERVICE._serialized_end=12924
  _NODEINFOGCSSERVICE._serialized_start=12927
  _NODEINFOGCSSERVICE._serialized_end=13397
  _TASKINFOGCSSERVICE._serialized_start=13400
  _TASKINFOGCSSERVICE._serialized_end=13583
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: src/ray/protobuf/event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1csrc/ray/protobuf/event.proto\x12\x07ray.rpc\"\xf1\x04\n\x05\x45vent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12:\n\x0bsource_type\x18\x02 \x01(\x0e\x32\x19.ray.rpc.Event.SourceTypeR\nsourceType\x12\'\n\x0fsource_hostname\x18\x03 \x01(\tR\x0esourceHostname\x12\x1d\n\nsource_pid\x18\x04 \x01(\x05R\tsourcePid\x12\x33\n\x08severity\x18\x05 \x01(\x0e\x32\x17.ray.rpc.Event.SeverityR\x08severity\x12\x14\n\x05label\x18\x06 \x01(\tR\x05label\x12\x18\n\x07message\x18\x07 \x01(\tR\x07message\x12\x1c\n\ttimestamp\x18\x08 \x01(\x03R\ttimestamp\x12\x45\n\rcustom_fields\x18\t \x03(\x0b\x32 .ray.rpc.Event.CustomFieldsEntryR\x0c\x63ustomFields\x1a?\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"o\n\nSourceType\x12\n\n\x06\x43OMMON\x10\x00\x12\x0f\n\x0b\x43ORE_WORKER\x10\x01\x12\x07\n\x03GCS\x10\x02\x12\n\n\x06RAYLET\x10\x03\x12\x15\n\x11\x43LUSTER_LIFECYCLE\x10\x04\x12\x0e\n\nAUTOSCALER\x10\x05\x12\x08\n\x04JOBS\x10\x06\"M\n\x08Severity\x12\x08\n\x04INFO\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\t\n\x05\x46\x41TAL\x10\x03\x12\t\n\x05\x44\x45\x42UG\x10\x04\x12\t\n\x05TRACE\x10\x05\"6\n\x11ReportEventsReply\x12!\n\x0csend_success\x18\x01 \x01(\x08R\x0bsendSuccess\":\n\x13ReportEventsRequest\x12#\n\revent_strings\x18\x01 \x03(\tR\x0c\x65ventStrings2^\n\x12ReportEventService\x12H\n\x0cReportEvents\x12\x1c.ray.rpc.ReportEventsRequest\x1a\x1a.ray.rpc.ReportEventsReplyB\x03\xf8\x01\x01\x62\x06proto3')



_EVENT = DESCRIPTOR.message_types_by_name['Event']
_EVENT_CUSTOMFIELDSENTRY = _EVENT.nested_types_by_name['CustomFieldsEntry']
_REPORTEVENTSREPLY = DESCRIPTOR.message_types_by_name['ReportEventsReply']
_REPORTEVENTSREQUEST = DESCRIPTOR.message_types_by_name['ReportEventsRequest']
_EVENT_SOURCETYPE = _EVENT.enum_types_by_name['SourceType']
_EVENT_SEVERITY = _EVENT.enum_types_by_name['Severity']
Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {

  'CustomFieldsEntry' : _reflection.GeneratedProtocolMessageType('CustomFieldsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_CUSTOMFIELDSENTRY,
    '__module__' : 'src.ray.protobuf.event_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.Event.CustomFieldsEntry)
    })
  ,
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'src.ray.protobuf.event_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.Event)
  })
_sym_db.RegisterMessage(Event)
_sym_db.RegisterMessage(Event.CustomFieldsEntry)

ReportEventsReply = _reflection.GeneratedProtocolMessageType('ReportEventsReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTEVENTSREPLY,
  '__module__' : 'src.ray.protobuf.event_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportEventsReply)
  })
_sym_db.RegisterMessage(ReportEventsReply)

ReportEventsRequest = _reflection.GeneratedProtocolMessageType('ReportEventsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTEVENTSREQUEST,
  '__module__' : 'src.ray.protobuf.event_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportEventsRequest)
  })
_sym_db.RegisterMessage(ReportEventsRequest)

_REPORTEVENTSERVICE = DESCRIPTOR.services_by_name['ReportEventService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _EVENT_CUSTOMFIELDSENTRY._options = None
  _EVENT_CUSTOMFIELDSENTRY._serialized_options = b'8\001'
  _EVENT._serialized_start=42
  _EVENT._serialized_end=667
  _EVENT_CUSTOMFIELDSENTRY._serialized_start=412
  _EVENT_CUSTOMFIELDSENTRY._serialized_end=475
  _EVENT_SOURCETYPE._serialized_start=477
  _EVENT_SOURCETYPE._serialized_end=588
  _EVENT_SEVERITY._serialized_start=590
  _EVENT_SEVERITY._serialized_end=667
  _REPORTEVENTSREPLY._serialized_start=669
  _REPORTEVENTSREPLY._serialized_end=723
  _REPORTEVENTSREQUEST._serialized_start=725
  _REPORTEVENTSREQUEST._serialized_end=783
  _REPORTEVENTSERVICE._serialized_start=785
  _REPORTEVENTSERVICE._serialized_end=879
# @@protoc_insertion_point(module_scope)



from typing import Optional

from ray.rllib.utils.annotations import override, PublicAPI
from ray.rllib.utils.framework import try_import_tf, try_import_torch
from ray.rllib.utils.schedules.schedule import Schedule
from ray.rllib.utils.typing import TensorType

tf1, tf, tfv = try_import_tf()
torch, _ = try_import_torch()


@PublicAPI
class PolynomialSchedule(Schedule):
    """Polynomial interpolation between `initial_p` and `final_p`.

    Over `schedule_timesteps`. After this many time steps, always returns
    `final_p`.
    """

    def __init__(
        self,
        schedule_timesteps: int,
        final_p: float,
        framework: Optional[str],
        initial_p: float = 1.0,
        power: float = 2.0,
    ):
        """Initializes a PolynomialSchedule instance.

        Args:
            schedule_timesteps: Number of time steps for which to
                linearly anneal initial_p to final_p
            final_p: Final output value.
            framework: The framework descriptor string, e.g. "tf",
                "torch", or None.
            initial_p: Initial output value.
            power: The exponent to use (default: quadratic).
        """
        super().__init__(framework=framework)
        assert schedule_timesteps > 0
        self.schedule_timesteps = schedule_timesteps
        self.final_p = final_p
        self.initial_p = initial_p
        self.power = power

    @override(Schedule)
    def _value(self, t: TensorType) -> TensorType:
        """Returns the result of:
        final_p + (initial_p - final_p) * (1 - `t`/t_max) ** power
        """
        if self.framework == "torch" and torch and isinstance(t, torch.Tensor):
            t = t.float()
        t = min(t, self.schedule_timesteps)
        return (
            self.final_p
            + (self.initial_p - self.final_p)
            * (1.0 - (t / self.schedule_timesteps)) ** self.power
        )

    @override(Schedule)
    def _tf_value_op(self, t: TensorType) -> TensorType:
        t = tf.math.minimum(t, self.schedule_timesteps)
        return (
            self.final_p
            + (self.initial_p - self.final_p)
            * (1.0 - (t / self.schedule_timesteps)) ** self.power
        )



import logging
import json
import os
from packaging import version
import tempfile
import re
from typing import Any, Dict, Union

import ray
from ray.air.checkpoint import Checkpoint
from ray.rllib.utils.serialization import NOT_SERIALIZABLE, serialize_type
from ray.util import log_once
from ray.util.annotations import PublicAPI

logger = logging.getLogger(__name__)

# The current checkpoint version used by RLlib for Algorithm and Policy checkpoints.
# History:
# 0.1: Ray 2.0.0
#  A single `checkpoint-[iter num]` file for Algorithm checkpoints
#  within the checkpoint directory. Policy checkpoints not supported across all
#  DL frameworks.

# 1.0: Ray >=2.1.0
#  An algorithm_state.pkl file for the state of the Algorithm (excluding
#  individual policy states).
#  One sub-dir inside the "policies" sub-dir for each policy with a
#  dedicated policy_state.pkl in it for the policy state.

# 1.1: Same as 1.0, but has a new "format" field in the rllib_checkpoint.json file
# indicating, whether the checkpoint is `cloudpickle` (default) or `msgpack`.

# 1.2: Introduces the checkpoint for the new Learner API if the Learner api is enabled.

CHECKPOINT_VERSION = version.Version("1.1")
CHECKPOINT_VERSION_LEARNER = version.Version("1.2")


@PublicAPI(stability="alpha")
def get_checkpoint_info(checkpoint: Union[str, Checkpoint]) -> Dict[str, Any]:
    """Returns a dict with information about a Algorithm/Policy checkpoint.

    If the given checkpoint is a >=v1.0 checkpoint directory, try reading all
    information from the contained `rllib_checkpoint.json` file.

    Args:
        checkpoint: The checkpoint directory (str) or an AIR Checkpoint object.

    Returns:
        A dict containing the keys:
        "type": One of "Policy" or "Algorithm".
        "checkpoint_version": A version tuple, e.g. v1.0, indicating the checkpoint
        version. This will help RLlib to remain backward compatible wrt. future
        Ray and checkpoint versions.
        "checkpoint_dir": The directory with all the checkpoint files in it. This might
        be the same as the incoming `checkpoint` arg.
        "state_file": The main file with the Algorithm/Policy's state information in it.
        This is usually a pickle-encoded file.
        "policy_ids": An optional set of PolicyIDs in case we are dealing with an
        Algorithm checkpoint. None if `checkpoint` is a Policy checkpoint.
    """
    # Default checkpoint info.
    info = {
        "type": "Algorithm",
        "format": "cloudpickle",
        "checkpoint_version": CHECKPOINT_VERSION,
        "checkpoint_dir": None,
        "state_file": None,
        "policy_ids": None,
    }

    # `checkpoint` is a Checkpoint instance: Translate to directory and continue.
    if isinstance(checkpoint, Checkpoint):
        tmp_dir = tempfile.mkdtemp()
        checkpoint.to_directory(tmp_dir)
        checkpoint = tmp_dir

    # Checkpoint is dir.
    if os.path.isdir(checkpoint):
        info.update({"checkpoint_dir": checkpoint})

        # Figure out whether this is an older checkpoint format
        # (with a `checkpoint-\d+` file in it).
        for file in os.listdir(checkpoint):
            path_file = os.path.join(checkpoint, file)
            if os.path.isfile(path_file):
                if re.match("checkpoint-\\d+", file):
                    info.update(
                        {
                            "checkpoint_version": version.Version("0.1"),
                            "state_file": path_file,
                        }
                    )
                    return info

        # No old checkpoint file found.

        # If rllib_checkpoint.json file present, read available information from it
        # and then continue with the checkpoint analysis (possibly overriding further
        # information).
        if os.path.isfile(os.path.join(checkpoint, "rllib_checkpoint.json")):
            with open(os.path.join(checkpoint, "rllib_checkpoint.json")) as f:
                rllib_checkpoint_info = json.load(fp=f)
            if "checkpoint_version" in rllib_checkpoint_info:
                rllib_checkpoint_info["checkpoint_version"] = version.Version(
                    rllib_checkpoint_info["checkpoint_version"]
                )
            info.update(rllib_checkpoint_info)
        else:
            # No rllib_checkpoint.json file present: Warn and continue trying to figure
            # out checkpoint info ourselves.
            if log_once("no_rllib_checkpoint_json_file"):
                logger.warning(
                    "No `rllib_checkpoint.json` file found in checkpoint directory "
                    f"{checkpoint}! Trying to extract checkpoint info from other files "
                    f"found in that dir."
                )

        # Policy checkpoint file found.
        for extension in ["pkl", "msgpck"]:
            if os.path.isfile(os.path.join(checkpoint, "policy_state." + extension)):
                info.update(
                    {
                        "type": "Policy",
                        "format": "cloudpickle" if extension == "pkl" else "msgpack",
                        "checkpoint_version": CHECKPOINT_VERSION,
                        "state_file": os.path.join(
                            checkpoint, f"policy_state.{extension}"
                        ),
                    }
                )
                return info

        # Valid Algorithm checkpoint >v0 file found?
        format = None
        for extension in ["pkl", "msgpck"]:
            state_file = os.path.join(checkpoint, f"algorithm_state.{extension}")
            if os.path.isfile(state_file):
                format = "cloudpickle" if extension == "pkl" else "msgpack"
                break
        if format is None:
            raise ValueError(
                "Given checkpoint does not seem to be valid! No file with the name "
                "`algorithm_state.[pkl|msgpck]` (or `checkpoint-[0-9]+`) found."
            )

        info.update(
            {
                "format": format,
                "state_file": state_file,
            }
        )

        # Collect all policy IDs in the sub-dir "policies/".
        policies_dir = os.path.join(checkpoint, "policies")
        if os.path.isdir(policies_dir):
            policy_ids = set()
            for policy_id in os.listdir(policies_dir):
                policy_ids.add(policy_id)
            info.update({"policy_ids": policy_ids})

    # Checkpoint is a file: Use as-is (interpreting it as old Algorithm checkpoint
    # version).
    elif os.path.isfile(checkpoint):
        info.update(
            {
                "checkpoint_version": version.Version("0.1"),
                "checkpoint_dir": os.path.dirname(checkpoint),
                "state_file": checkpoint,
            }
        )

    else:
        raise ValueError(
            f"Given checkpoint ({checkpoint}) not found! Must be a "
            "checkpoint directory (or a file for older checkpoint versions)."
        )

    return info


@PublicAPI(stability="beta")
def convert_to_msgpack_checkpoint(
    checkpoint: Union[str, Checkpoint],
    msgpack_checkpoint_dir: str,
) -> str:
    """Converts an Algorithm checkpoint (pickle based) to a msgpack based one.

    Msgpack has the advantage of being python version independent.

    Args:
        checkpoint: The directory, in which to find the Algorithm checkpoint (pickle
            based).
        msgpack_checkpoint_dir: The directory, in which to create the new msgpack
            based checkpoint.

    Returns:
        The directory in which the msgpack checkpoint has been created. Note that
        this is the same as `msgpack_checkpoint_dir`.
    """
    from ray.rllib.algorithms import Algorithm
    from ray.rllib.utils.policy import validate_policy_id

    # Try to import msgpack and msgpack_numpy.
    msgpack = try_import_msgpack(error=True)

    # Restore the Algorithm using the python version dependent checkpoint.
    algo = Algorithm.from_checkpoint(checkpoint)
    state = algo.__getstate__()

    # Convert all code in state into serializable data.
    # Serialize the algorithm class.
    state["algorithm_class"] = serialize_type(state["algorithm_class"])
    # Serialize the algorithm's config object.
    state["config"] = state["config"].serialize()

    # Extract policy states from worker state (Policies get their own
    # checkpoint sub-dirs).
    policy_states = {}
    if "worker" in state and "policy_states" in state["worker"]:
        policy_states = state["worker"].pop("policy_states", {})

    # Policy mapping fn.
    state["worker"]["policy_mapping_fn"] = NOT_SERIALIZABLE
    # Is Policy to train function.
    state["worker"]["is_policy_to_train"] = NOT_SERIALIZABLE

    # Add RLlib checkpoint version (as string).
    if state["config"]["_enable_learner_api"]:
        state["checkpoint_version"] = str(CHECKPOINT_VERSION_LEARNER)
    else:
        state["checkpoint_version"] = str(CHECKPOINT_VERSION)

    # Write state (w/o policies) to disk.
    state_file = os.path.join(msgpack_checkpoint_dir, "algorithm_state.msgpck")
    with open(state_file, "wb") as f:
        msgpack.dump(state, f)

    # Write rllib_checkpoint.json.
    with open(os.path.join(msgpack_checkpoint_dir, "rllib_checkpoint.json"), "w") as f:
        json.dump(
            {
                "type": "Algorithm",
                "checkpoint_version": state["checkpoint_version"],
                "format": "msgpack",
                "state_file": state_file,
                "policy_ids": list(policy_states.keys()),
                "ray_version": ray.__version__,
                "ray_commit": ray.__commit__,
            },
            f,
        )

    # Write individual policies to disk, each in their own sub-directory.
    for pid, policy_state in policy_states.items():
        # From here on, disallow policyIDs that would not work as directory names.
        validate_policy_id(pid, error=True)
        policy_dir = os.path.join(msgpack_checkpoint_dir, "policies", pid)
        os.makedirs(policy_dir, exist_ok=True)
        policy = algo.get_policy(pid)
        policy.export_checkpoint(
            policy_dir,
            policy_state=policy_state,
            checkpoint_format="msgpack",
        )

    # Release all resources used by the Algorithm.
    algo.stop()

    return msgpack_checkpoint_dir


@PublicAPI
def try_import_msgpack(error: bool = False):
    """Tries importing msgpack and msgpack_numpy and returns the patched msgpack module.

    Returns None if error is False and msgpack or msgpack_numpy is not installed.
    Raises an error, if error is True and the modules could not be imported.

    Args:
        error: Whether to raise an error if msgpack/msgpack_numpy cannot be imported.

    Returns:
        The `msgpack` module.

    Raises:
        ImportError: If error=True and msgpack/msgpack_numpy is not installed.
    """
    try:
        import msgpack
        import msgpack_numpy

        # Make msgpack_numpy look like msgpack.
        msgpack_numpy.patch()

        return msgpack

    except Exception:
        if error:
            raise ImportError(
                "Could not import or setup msgpack and msgpack_numpy! "
                "Try running `pip install msgpack msgpack_numpy` first."
            )



from filelock import FileLock
import hashlib
import os
from pathlib import Path

import ray


RAY_LOCKFILE_DIR = "_ray_lockfiles"


class TempFileLock:
    """FileLock wrapper that uses temporary file locks.

    The temporary directory that these locks are saved to can be configured via
    the `RAY_TMPDIR` environment variable.

    Args:
        path: The file path that this temporary file lock is used for.
            This will be used to generate the lockfile filename.
            Ex: For concurrent writes to a file, this is the common filepath
            that multiple processes are writing to.
        **kwargs: Additional keyword arguments to pass to the underlying `FileLock`.
    """

    def __init__(self, path: str, **kwargs):
        self.path = path
        temp_dir = Path(ray._private.utils.get_user_temp_dir()).resolve()
        self._lock_dir = temp_dir / RAY_LOCKFILE_DIR
        self._path_hash = hashlib.md5(
            str(Path(self.path).resolve()).encode("utf-8")
        ).hexdigest()
        self._lock_path = self._lock_dir / f"{self._path_hash}.lock"

        os.makedirs(str(self._lock_dir), exist_ok=True)
        self._lock = FileLock(self._lock_path, **kwargs)

    def __enter__(self):
        self._lock.acquire()
        return self

    def __exit__(self, type, value, traceback):
        self._lock.release()

    def __getattr__(self, name):
        return getattr(self._lock, name)



from typing import Mapping, Any
from ray.rllib.core.rl_module import RLModule
from ray.rllib.policy.sample_batch import SampleBatch
import tree
import pathlib
import gymnasium as gym


class RandomRLModule(RLModule):
    def _random_forward(self, batch, **kwargs):
        obs_batch_size = len(tree.flatten(batch[SampleBatch.OBS])[0])
        actions = [self.config.action_space.sample() for _ in range(obs_batch_size)]
        return {SampleBatch.ACTIONS: actions}

    def _forward_inference(self, batch, **kwargs):
        return self._random_forward(batch, **kwargs)

    def _forward_exploration(self, batch, **kwargs):
        return self._random_forward(batch, **kwargs)

    def _forward_train(self, *args, **kwargs):
        raise NotImplementedError("This RLM should only run in evaluation.")

    def output_specs_inference(self):
        return [SampleBatch.ACTIONS]

    def output_specs_exploration(self):
        return [SampleBatch.ACTIONS]

    def get_state(self) -> Mapping[str, Any]:
        return {}

    def set_state(self, state_dict: Mapping[str, Any]) -> None:
        pass

    def _module_state_file_name(self) -> pathlib.Path:
        return pathlib.Path("random_rl_module_dummy_state")

    def save_state(self, path) -> None:
        pass

    def compile(self, *args, **kwargs):
        """Dummy method for compatibility with TorchRLModule.

        This is hit when RolloutWorker tries to compile TorchRLModule."""
        pass

    @classmethod
    def from_model_config(
        cls,
        observation_space: gym.Space,
        action_space: gym.Space,
        *,
        model_config_dict: Mapping[str, Any],
    ) -> "RLModule":
        return cls(action_space)



import argparse

import ray
from ray import tune
from ray.train.torch import TorchTrainer
from ray.air.config import ScalingConfig
from ray.tune.tune_config import TuneConfig
from ray.tune.tuner import Tuner

from torch_regression_example import train_func, get_datasets


def tune_linear(num_workers, num_samples, use_gpu):
    train_dataset, val_dataset = get_datasets()

    config = {"lr": 1e-2, "hidden_size": 1, "batch_size": 4, "epochs": 3}

    trainer = TorchTrainer(
        train_loop_per_worker=train_func,
        train_loop_config=config,
        scaling_config=ScalingConfig(num_workers=num_workers, use_gpu=use_gpu),
        datasets={"train": train_dataset, "validation": val_dataset},
    )

    tuner = Tuner(
        trainer,
        param_space={
            "train_loop_config": {
                "lr": tune.loguniform(1e-4, 1e-1),
                "batch_size": tune.choice([4, 16, 32]),
                "epochs": 3,
            }
        },
        tune_config=TuneConfig(num_samples=num_samples, metric="loss", mode="min"),
    )
    result_grid = tuner.fit()
    best_result = result_grid.get_best_result()
    print(best_result)
    return best_result


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--smoke-test",
        action="store_true",
        default=False,
        help="Finish quickly for testing.",
    )
    parser.add_argument(
        "--address", required=False, type=str, help="the address to use for Ray"
    )
    parser.add_argument(
        "--num-workers",
        "-n",
        type=int,
        default=2,
        help="Sets number of workers for training.",
    )
    parser.add_argument(
        "--num-samples",
        type=int,
        default=2,
        help="Sets number of samples for training.",
    )
    parser.add_argument(
        "--use-gpu", action="store_true", default=False, help="Use GPU for training."
    )

    args = parser.parse_args()

    if args.smoke_test:
        # 2 workers, 1 for trainer, 1 for datasets
        ray.init(num_cpus=4)
        tune_linear(num_workers=2, num_samples=1, use_gpu=False)
    else:
        ray.init(address=args.address)
        tune_linear(
            num_workers=args.num_workers,
            use_gpu=args.use_gpu,
            num_samples=args.num_samples,
        )



from gymnasium.spaces import Box, Dict, Discrete
import numpy as np

from ray.rllib.examples.env.random_env import RandomEnv


class ActionMaskEnv(RandomEnv):
    """A randomly acting environment that publishes an action-mask each step."""

    def __init__(self, config):
        super().__init__(config)
        self._skip_env_checking = True
        # Masking only works for Discrete actions.
        assert isinstance(self.action_space, Discrete)
        # Add action_mask to observations.
        self.observation_space = Dict(
            {
                "action_mask": Box(0.0, 1.0, shape=(self.action_space.n,)),
                "observations": self.observation_space,
            }
        )
        self.valid_actions = None

    def reset(self, *, seed=None, options=None):
        obs, info = super().reset()
        self._fix_action_mask(obs)
        return obs, info

    def step(self, action):
        # Check whether action is valid.
        if not self.valid_actions[action]:
            raise ValueError(
                f"Invalid action sent to env! " f"valid_actions={self.valid_actions}"
            )
        obs, rew, done, truncated, info = super().step(action)
        self._fix_action_mask(obs)
        return obs, rew, done, truncated, info

    def _fix_action_mask(self, obs):
        # Fix action-mask: Everything larger 0.5 is 1.0, everything else 0.0.
        self.valid_actions = np.round(obs["action_mask"])
        obs["action_mask"] = self.valid_actions



import functools
from typing import Optional

import numpy as np

from ray.rllib.core.models.base import Model
from ray.rllib.core.models.configs import (
    CNNTransposeHeadConfig,
    FreeLogStdMLPHeadConfig,
    MLPHeadConfig,
)
from ray.rllib.core.models.specs.checker import SpecCheckingError
from ray.rllib.core.models.specs.specs_base import Spec
from ray.rllib.core.models.specs.specs_base import TensorSpec
from ray.rllib.core.models.torch.base import TorchModel
from ray.rllib.core.models.torch.primitives import TorchCNNTranspose, TorchMLP
from ray.rllib.utils.annotations import override
from ray.rllib.utils.framework import try_import_torch

torch, nn = try_import_torch()


def auto_fold_unfold_time(input_spec: str):
    """Automatically folds/unfolds the time dimension of a tensor.

    This is useful when calling the model requires a batch dimension only, but the
    input data has a batch- and a time-dimension. This decorator will automatically
    fold the time dimension into the batch dimension before calling the model and
    unfold the batch dimension back into the time dimension after calling the model.

    Args:
        input_spec: The input spec of the model.

    Returns:
        A decorator that automatically folds/unfolds the time_dimension if present.
    """

    def decorator(func):
        @functools.wraps(func)
        def wrapper(self, input_data, **kwargs):
            if not hasattr(self, input_spec):
                raise ValueError(
                    "The model must have an input_specs attribute to "
                    "automatically fold/unfold the time dimension."
                )
            if not torch.is_tensor(input_data):
                raise ValueError(
                    f"input_data must be a torch.Tensor to fold/unfold "
                    f"time automatically, but got {type(input_data)}."
                )
            # Attempt to fold/unfold the time dimension.
            actual_shape = list(input_data.shape)
            spec = getattr(self, input_spec)

            try:
                # Validate the input data against the input spec to find out it we
                # should attempt to fold/unfold the time dimension.
                spec.validate(input_data)
            except ValueError as original_error:
                # Attempt to fold/unfold the time dimension.
                # Calculate a new shape for the input data.
                b, t = actual_shape[:2]
                other_dims = actual_shape[2:]
                reshaped_b = b * t
                new_shape = tuple([reshaped_b] + other_dims)
                reshaped_inputs = input_data.reshape(new_shape)
                try:
                    spec.validate(reshaped_inputs)
                except ValueError as new_error:
                    raise SpecCheckingError(
                        f"Attempted to call {func} with input data of shape "
                        f"{actual_shape}. RLlib attempts to automatically fold/unfold "
                        f"the time dimension because {actual_shape} does not match the "
                        f"input spec {spec}. In an attempt to fold the time "
                        f"dimensions to possibly fit the input specs of {func}, "
                        f"RLlib has calculated the new shape {new_shape} and "
                        f"reshaped the input data to {reshaped_inputs}. However, "
                        f"the input data still does not match the input spec. "
                        f"\nOriginal error: \n{original_error}. \nNew error:"
                        f" \n{new_error}."
                    )
                # Call the actual wrapped function
                outputs = func(self, reshaped_inputs, **kwargs)
                # Attempt to unfold the time dimension.
                return outputs.reshape((b, t) + tuple(outputs.shape[1:]))
            # If above we could validate the spec, we can call the actual wrapped
            # function.
            return func(self, input_data, **kwargs)

        return wrapper

    return decorator


class TorchMLPHead(TorchModel):
    def __init__(self, config: MLPHeadConfig) -> None:
        super().__init__(config)

        self.net = TorchMLP(
            input_dim=config.input_dims[0],
            hidden_layer_dims=config.hidden_layer_dims,
            hidden_layer_activation=config.hidden_layer_activation,
            hidden_layer_use_layernorm=config.hidden_layer_use_layernorm,
            hidden_layer_use_bias=config.hidden_layer_use_bias,
            output_dim=config.output_layer_dim,
            output_activation=config.output_layer_activation,
            output_use_bias=config.output_layer_use_bias,
        )

    @override(Model)
    def get_input_specs(self) -> Optional[Spec]:
        return TensorSpec("b, d", d=self.config.input_dims[0], framework="torch")

    @override(Model)
    def get_output_specs(self) -> Optional[Spec]:
        return TensorSpec("b, d", d=self.config.output_dims[0], framework="torch")

    @override(Model)
    @auto_fold_unfold_time("input_specs")
    def _forward(self, inputs: torch.Tensor, **kwargs) -> torch.Tensor:
        return self.net(inputs)


class TorchFreeLogStdMLPHead(TorchModel):
    """An MLPHead that implements floating log stds for Gaussian distributions."""

    def __init__(self, config: FreeLogStdMLPHeadConfig) -> None:
        super().__init__(config)

        assert config.output_dims[0] % 2 == 0, "output_dims must be even for free std!"
        self._half_output_dim = config.output_dims[0] // 2

        self.net = TorchMLP(
            input_dim=config.input_dims[0],
            hidden_layer_dims=config.hidden_layer_dims,
            hidden_layer_activation=config.hidden_layer_activation,
            hidden_layer_use_layernorm=config.hidden_layer_use_layernorm,
            hidden_layer_use_bias=config.hidden_layer_use_bias,
            output_dim=self._half_output_dim,
            output_activation=config.output_layer_activation,
            output_use_bias=config.output_layer_use_bias,
        )

        self.log_std = torch.nn.Parameter(
            torch.as_tensor([0.0] * self._half_output_dim)
        )

    @override(Model)
    def get_input_specs(self) -> Optional[Spec]:
        return TensorSpec("b, d", d=self.config.input_dims[0], framework="torch")

    @override(Model)
    def get_output_specs(self) -> Optional[Spec]:
        return TensorSpec("b, d", d=self.config.output_dims[0], framework="torch")

    @override(Model)
    @auto_fold_unfold_time("input_specs")
    def _forward(self, inputs: torch.Tensor, **kwargs) -> torch.Tensor:
        # Compute the mean first, then append the log_std.
        mean = self.net(inputs)

        return torch.cat(
            [mean, self.log_std.unsqueeze(0).repeat([len(mean), 1])], axis=1
        )


class TorchCNNTransposeHead(TorchModel):
    def __init__(self, config: CNNTransposeHeadConfig) -> None:
        super().__init__(config)

        # Initial, inactivated Dense layer (always w/ bias).
        # This layer is responsible for getting the incoming tensor into a proper
        # initial image shape (w x h x filters) for the suceeding Conv2DTranspose stack.
        self.initial_dense = nn.Linear(
            in_features=config.input_dims[0],
            out_features=int(np.prod(config.initial_image_dims)),
            bias=True,
        )

        # The main CNNTranspose stack.
        self.cnn_transpose_net = TorchCNNTranspose(
            input_dims=config.initial_image_dims,
            cnn_transpose_filter_specifiers=config.cnn_transpose_filter_specifiers,
            cnn_transpose_activation=config.cnn_transpose_activation,
            cnn_transpose_use_layernorm=config.cnn_transpose_use_layernorm,
            cnn_transpose_use_bias=config.cnn_transpose_use_bias,
        )

    @override(Model)
    def get_input_specs(self) -> Optional[Spec]:
        return TensorSpec("b, d", d=self.config.input_dims[0], framework="torch")

    @override(Model)
    def get_output_specs(self) -> Optional[Spec]:
        return TensorSpec(
            "b, w, h, c",
            w=self.config.output_dims[0],
            h=self.config.output_dims[1],
            c=self.config.output_dims[2],
            framework="torch",
        )

    @override(Model)
    @auto_fold_unfold_time("input_specs")
    def _forward(self, inputs: torch.Tensor, **kwargs) -> torch.Tensor:
        out = self.initial_dense(inputs)
        # Reshape to initial 3D (image-like) format to enter CNN transpose stack.
        out = out.reshape((-1,) + tuple(self.config.initial_image_dims))
        out = self.cnn_transpose_net(out)
        # Add 0.5 to center (always non-activated, non-normalized) outputs more
        # around 0.0.
        return out + 0.5



from typing import List, Union
from ray.rllib.utils.framework import try_import_torch

torch, nn = try_import_torch()


def make_time_major(
    tensor: Union["torch.Tensor", List["torch.Tensor"]],
    *,
    trajectory_len: int = None,
    recurrent_seq_len: int = None,
):
    """Swaps batch and trajectory axis.

    Args:
        tensor: A tensor or list of tensors to swap the axis of.
            NOTE: Each tensor must have the shape [B * T] where B is the batch size and
            T is the trajectory length.
        trajectory_len: The length of each trajectory being transformed.
            If None then `recurrent_seq_len` must be set.
        recurrent_seq_len: Sequence lengths if recurrent.
            If None then `trajectory_len` must be set.

    Returns:
        res: A tensor with swapped axes or a list of tensors with
        swapped axes.
    """
    if isinstance(tensor, (list, tuple)):
        return [
            make_time_major(_tensor, trajectory_len, recurrent_seq_len)
            for _tensor in tensor
        ]

    assert (trajectory_len != recurrent_seq_len) and (
        trajectory_len is None or recurrent_seq_len is None
    ), "Either trajectory_len or recurrent_seq_len must be set."

    if recurrent_seq_len:
        B = recurrent_seq_len.shape[0]
        T = tensor.shape[0] // B
    else:
        # Important: chop the tensor into batches at known episode cut
        # boundaries.
        # TODO: (sven) this is kind of a hack and won't work for
        #  batch_mode=complete_episodes.
        T = trajectory_len
        B = tensor.shape[0] // T
    rs = torch.reshape(tensor, [B, T] + list(tensor.shape[1:]))

    # Swap B and T axes.
    res = torch.transpose(rs, 1, 0)

    return res


def vtrace_torch(
    *,
    target_action_log_probs: "torch.Tensor",
    behaviour_action_log_probs: "torch.Tensor",
    discounts: "torch.Tensor",
    rewards: "torch.Tensor",
    values: "torch.Tensor",
    bootstrap_value: "torch.Tensor",
    clip_rho_threshold: Union[float, "torch.Tensor"] = 1.0,
    clip_pg_rho_threshold: Union[float, "torch.Tensor"] = 1.0,
):
    """V-trace for softmax policies implemented with torch.

    Calculates V-trace actor critic targets for softmax polices as described in
    "IMPALA: Scalable Distributed Deep-RL with Importance Weighted Actor-Learner
    Architectures" by Espeholt, Soyer, Munos et al. (https://arxiv.org/abs/1802.01561)

    The V-trace implementation used here closely resembles the one found in the
    scalable-agent repository by Google DeepMind, available at
    https://github.com/deepmind/scalable_agent. This version has been optimized to
    minimize the number of floating-point operations required per V-Trace
    calculation, achieved through the use of dynamic programming techniques. It's
    important to note that the mathematical expressions used in this implementation
    may appear quite different from those presented in the IMPALA paper.

    The following terminology applies:
        - `target policy` refers to the policy we are interested in improving.
        - `behaviour policy` refers to the policy that generated the given
            rewards and actions.
        - `T` refers to the time dimension. This is usually either the length of the
            trajectory or the length of the sequence if recurrent.
        - `B` refers to the batch size.

    Args:
        target_action_log_probs: Action log probs from the target policy. A float32
            tensor of shape [T, B].
        behaviour_action_log_probs: Action log probs from the behaviour policy. A
            float32 tensor of shape [T, B].
        discounts: A float32 tensor of shape [T, B] with the discount encountered when
            following the behaviour policy. This will be 0 for terminal timesteps
            (done=True) and gamma (the discount factor) otherwise.
        rewards: A float32 tensor of shape [T, B] with the rewards generated by
            following the behaviour policy.
        values: A float32 tensor of shape [T, B] with the value function estimates
            wrt. the target policy.
        bootstrap_value: A float32 of shape [B] with the value function estimate at
            time T.
        clip_rho_threshold: A scalar float32 tensor with the clipping threshold for
            importance weights (rho) when calculating the baseline targets (vs).
            rho^bar in the paper.
        clip_pg_rho_threshold: A scalar float32 tensor with the clipping threshold
            on rho_s in \rho_s \delta log \pi(a|x) (r + \gamma v_{s+1} - V(x_s)).
    """
    log_rhos = target_action_log_probs - behaviour_action_log_probs

    rhos = torch.exp(log_rhos)
    if clip_rho_threshold is not None:
        clipped_rhos = torch.clamp(rhos, max=clip_rho_threshold)
    else:
        clipped_rhos = rhos

    cs = torch.clamp(rhos, max=1.0)
    # Append bootstrapped value to get [v1, ..., v_t+1]
    values_t_plus_1 = torch.cat(
        [values[1:], torch.unsqueeze(bootstrap_value, 0)], axis=0
    )

    deltas = clipped_rhos * (rewards + discounts * values_t_plus_1 - values)

    # Only move the for-loop to CPU.
    discounts_cpu = discounts.to("cpu")
    cs_cpu = cs.to("cpu")
    deltas_cpu = deltas.to("cpu")
    vs_minus_v_xs_cpu = [torch.zeros_like(bootstrap_value, device="cpu")]
    for i in reversed(range(len(discounts_cpu))):
        discount_t, c_t, delta_t = discounts_cpu[i], cs_cpu[i], deltas_cpu[i]
        vs_minus_v_xs_cpu.append(delta_t + discount_t * c_t * vs_minus_v_xs_cpu[-1])
    vs_minus_v_xs_cpu = torch.stack(vs_minus_v_xs_cpu[1:])
    # Move results back to GPU - if applicable.
    vs_minus_v_xs = vs_minus_v_xs_cpu.to(deltas.device)

    # Reverse the results back to original order.
    vs_minus_v_xs = torch.flip(vs_minus_v_xs, dims=[0])

    # Add V(x_s) to get v_s.
    vs = torch.add(vs_minus_v_xs, values)

    # Advantage for policy gradient.
    vs_t_plus_1 = torch.cat([vs[1:], torch.unsqueeze(bootstrap_value, 0)], axis=0)
    if clip_pg_rho_threshold is not None:
        clipped_pg_rhos = torch.clamp(rhos, max=clip_pg_rho_threshold)
    else:
        clipped_pg_rhos = rhos
    pg_advantages = clipped_pg_rhos * (rewards + discounts * vs_t_plus_1 - values)

    # Make sure no gradients backpropagated through the returned values.
    return torch.detach(vs), torch.detach(pg_advantages)
